SCHEMA = {
  "typeName" : "AWS::EFS::FileSystem",
  "description" : "The ``AWS::EFS::FileSystem`` resource creates a new, empty file system in EFSlong (EFS). You must create a mount target ([AWS::EFS::MountTarget](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-efs-mounttarget.html)) to mount your EFS file system on an EC2 or other AWS cloud compute resource.",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-rpdk.git",
  "definitions" : {
    "Arn" : {
      "type" : "string"
    },
    "ElasticFileSystemTag" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Key" : {
          "type" : "string",
          "description" : "The tag key (String). The key can't start with ``aws:``."
        },
        "Value" : {
          "type" : "string",
          "description" : "The value of the tag key."
        }
      },
      "required" : [ "Value", "Key" ],
      "description" : "A tag is a key-value pair attached to a file system. Allowed characters in the ``Key`` and ``Value`` properties are letters, white space, and numbers that can be represented in UTF-8, and the following characters:``+ - = . _ : /``"
    },
    "LifecyclePolicy" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "TransitionToIA" : {
          "type" : "string",
          "description" : "The number of days after files were last accessed in primary storage (the Standard storage class) at which to move them to Infrequent Access (IA) storage. Metadata operations such as listing the contents of a directory don't count as file access events."
        },
        "TransitionToPrimaryStorageClass" : {
          "type" : "string",
          "description" : "Whether to move files back to primary (Standard) storage after they are accessed in IA or Archive storage. Metadata operations such as listing the contents of a directory don't count as file access events."
        },
        "TransitionToArchive" : {
          "type" : "string",
          "description" : "The number of days after files were last accessed in primary storage (the Standard storage class) at which to move them to Archive storage. Metadata operations such as listing the contents of a directory don't count as file access events."
        }
      },
      "description" : "Describes a policy used by Lifecycle management that specifies when to transition files into and out of the EFS storage classes. For more information, see [Managing file system storage](https://docs.aws.amazon.com/efs/latest/ug/lifecycle-management-efs.html).\n   +  Each ``LifecyclePolicy`` object can have only a single transition. This means that in a request body, ``LifecyclePolicies`` must be structured as an array of ``LifecyclePolicy`` objects, one object for each transition, ``TransitionToIA``, ``TransitionToArchive``, ``TransitionToPrimaryStorageClass``.\n  +  See the AWS::EFS::FileSystem examples for the correct ``LifecyclePolicy`` structure. Do not use the syntax shown on this page."
    },
    "BackupPolicy" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Status" : {
          "type" : "string",
          "enum" : [ "DISABLED", "ENABLED" ],
          "description" : "Set the backup policy status for the file system.\n  +  *ENABLED* - Turns automatic backups on for the file system. \n  +  *DISABLED* - Turns automatic backups off for the file system."
        }
      },
      "required" : [ "Status" ],
      "description" : "The backup policy turns automatic backups for the file system on or off."
    },
    "FileSystemProtection" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "ReplicationOverwriteProtection" : {
          "type" : "string",
          "enum" : [ "DISABLED", "ENABLED" ],
          "description" : "The status of the file system's replication overwrite protection.\n  +  ``ENABLED`` – The file system cannot be used as the destination file system in a replication configuration. The file system is writeable. Replication overwrite protection is ``ENABLED`` by default. \n  +  ``DISABLED`` – The file system can be used as the destination file system in a replication configuration. The file system is read-only and can only be modified by EFS replication.\n  +  ``REPLICATING`` – The file system is being used as the destination file system in a replication configuration. The file system is read-only and is modified only by EFS replication.\n  \n If the replication configuration is deleted, the file system's replication overwrite protection is re-enabled, the file system becomes writeable."
        }
      },
      "description" : "Describes the protection on the file system."
    },
    "ReplicationDestination" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Status" : {
          "type" : "string",
          "description" : "Describes the status of the replication configuration. For more information about replication status, see [Viewing replication details](https://docs.aws.amazon.com//efs/latest/ug/awsbackup.html#restoring-backup-efsmonitoring-replication-status.html) in the *Amazon EFS User Guide*."
        },
        "StatusMessage" : {
          "type" : "string",
          "description" : "Message that provides details about the ``PAUSED`` or ``ERRROR`` state of the replication destination configuration. For more information about replication status messages, see [Viewing replication details](https://docs.aws.amazon.com//efs/latest/ug/awsbackup.html#restoring-backup-efsmonitoring-replication-status.html) in the *Amazon EFS User Guide*."
        },
        "FileSystemId" : {
          "pattern" : "^(arn:aws[-a-z]*:elasticfilesystem:[0-9a-z-:]+:file-system/fs-[0-9a-f]{8,40}|fs-[0-9a-f]{8,40})$",
          "type" : "string",
          "description" : "The ID of the destination Amazon EFS file system."
        },
        "Region" : {
          "type" : "string",
          "description" : "The AWS-Region in which the destination file system is located.\n  For One Zone file systems, the replication configuration must specify the AWS-Region in which the destination file system is located."
        },
        "RoleArn" : {
          "type" : "string",
          "description" : "The Amazon Resource Name (ARN) of the current source file system in the replication configuration."
        },
        "AvailabilityZoneName" : {
          "type" : "string",
          "description" : "For One Zone file systems, the replication configuration must specify the Availability Zone in which the destination file system is located. \n Use the format ``us-east-1a`` to specify the Availability Zone. For more information about One Zone file systems, see [EFS file system types](https://docs.aws.amazon.com/efs/latest/ug/storage-classes.html) in the *Amazon EFS User Guide*.\n  One Zone file system type is not available in all Availability Zones in AWS-Regions where Amazon EFS is available."
        },
        "KmsKeyId" : {
          "type" : "string",
          "description" : "The ID of an kms-key-long used to protect the encrypted file system."
        }
      },
      "description" : "Describes the destination file system in the replication configuration."
    },
    "ReplicationConfiguration" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Destinations" : {
          "type" : "array",
          "uniqueItems" : True,
          "minItems" : 1,
          "maxItems" : 1,
          "items" : {
            "$ref" : "#/definitions/ReplicationDestination"
          },
          "description" : "An array of destination objects. Only one destination object is supported."
        }
      },
      "description" : "Describes the replication configuration for a specific file system."
    }
  },
  "properties" : {
    "FileSystemId" : {
      "type" : "string",
      "description" : ""
    },
    "Arn" : {
      "$ref" : "#/definitions/Arn",
      "description" : ""
    },
    "Encrypted" : {
      "type" : "boolean",
      "description" : "A Boolean value that, if True, creates an encrypted file system. When creating an encrypted file system, you have the option of specifying a KmsKeyId for an existing kms-key-long. If you don't specify a kms-key, then the default kms-key for EFS, ``/aws/elasticfilesystem``, is used to protect the encrypted file system."
    },
    "FileSystemTags" : {
      "type" : "array",
      "uniqueItems" : True,
      "items" : {
        "$ref" : "#/definitions/ElasticFileSystemTag"
      },
      "description" : "Use to create one or more tags associated with the file system. Each tag is a user-defined key-value pair. Name your file system on creation by including a ``\"Key\":\"Name\",\"Value\":\"{value}\"`` key-value pair. Each key must be unique. For more information, see [Tagging resources](https://docs.aws.amazon.com/general/latest/gr/aws_tagging.html) in the *General Reference Guide*."
    },
    "KmsKeyId" : {
      "type" : "string",
      "description" : "The ID of the kms-key-long to be used to protect the encrypted file system. This parameter is only required if you want to use a nondefault kms-key. If this parameter is not specified, the default kms-key for EFS is used. This ID can be in one of the following formats:\n  +  Key ID - A unique identifier of the key, for example ``1234abcd-12ab-34cd-56ef-1234567890ab``.\n  +  ARN - An Amazon Resource Name (ARN) for the key, for example ``arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab``.\n  +  Key alias - A previously created display name for a key, for example ``alias/projectKey1``.\n  +  Key alias ARN - An ARN for a key alias, for example ``arn:aws:kms:us-west-2:444455556666:alias/projectKey1``.\n  \n If ``KmsKeyId`` is specified, the ``Encrypted`` parameter must be set to True."
    },
    "LifecyclePolicies" : {
      "type" : "array",
      "uniqueItems" : True,
      "items" : {
        "$ref" : "#/definitions/LifecyclePolicy"
      },
      "description" : "An array of ``LifecyclePolicy`` objects that define the file system's ``LifecycleConfiguration`` object. A ``LifecycleConfiguration`` object informs Lifecycle management of the following:\n  +  When to move files in the file system from primary storage to IA storage.\n  +  When to move files in the file system from primary storage or IA storage to Archive storage.\n  +  When to move files that are in IA or Archive storage to primary storage.\n  \n  EFS requires that each ``LifecyclePolicy`` object have only a single transition. This means that in a request body, ``LifecyclePolicies`` needs to be structured as an array of ``LifecyclePolicy`` objects, one object for each transition, ``TransitionToIA``, ``TransitionToArchive````TransitionToPrimaryStorageClass``. See the example requests in the following section for more information."
    },
    "FileSystemProtection" : {
      "$ref" : "#/definitions/FileSystemProtection",
      "description" : "Describes the protection on the file system."
    },
    "PerformanceMode" : {
      "type" : "string",
      "description" : "The performance mode of the file system. We recommend ``generalPurpose`` performance mode for all file systems. File systems using the ``maxIO`` performance mode can scale to higher levels of aggregate throughput and operations per second with a tradeoff of slightly higher latencies for most file operations. The performance mode can't be changed after the file system has been created. The ``maxIO`` mode is not supported on One Zone file systems.\n  Due to the higher per-operation latencies with Max I/O, we recommend using General Purpose performance mode for all file systems.\n  Default is ``generalPurpose``."
    },
    "ProvisionedThroughputInMibps" : {
      "type" : "number",
      "description" : "The throughput, measured in mebibytes per second (MiBps), that you want to provision for a file system that you're creating. Required if ``ThroughputMode`` is set to ``provisioned``. Valid values are 1-3414 MiBps, with the upper limit depending on Region. To increase this limit, contact SUP. For more information, see [Amazon EFS quotas that you can increase](https://docs.aws.amazon.com/efs/latest/ug/limits.html#soft-limits) in the *Amazon EFS User Guide*."
    },
    "ThroughputMode" : {
      "type" : "string",
      "description" : "Specifies the throughput mode for the file system. The mode can be ``bursting``, ``provisioned``, or ``elastic``. If you set ``ThroughputMode`` to ``provisioned``, you must also set a value for ``ProvisionedThroughputInMibps``. After you create the file system, you can decrease your file system's Provisioned throughput or change between the throughput modes, with certain time restrictions. For more information, see [Specifying throughput with provisioned mode](https://docs.aws.amazon.com/efs/latest/ug/performance.html#provisioned-throughput) in the *Amazon EFS User Guide*. \n Default is ``bursting``."
    },
    "FileSystemPolicy" : {
      "type" : "object",
      "description" : "The ``FileSystemPolicy`` for the EFS file system. A file system policy is an IAM resource policy used to control NFS access to an EFS file system. For more information, see [Using to control NFS access to Amazon EFS](https://docs.aws.amazon.com/efs/latest/ug/iam-access-control-nfs-efs.html) in the *Amazon EFS User Guide*."
    },
    "BypassPolicyLockoutSafetyCheck" : {
      "description" : "(Optional) A boolean that specifies whether or not to bypass the ``FileSystemPolicy`` lockout safety check. The lockout safety check determines whether the policy in the request will lock out, or prevent, the IAM principal that is making the request from making future ``PutFileSystemPolicy`` requests on this file system. Set ``BypassPolicyLockoutSafetyCheck`` to ``True`` only when you intend to prevent the IAM principal that is making the request from making subsequent ``PutFileSystemPolicy`` requests on this file system. The default value is ``False``.",
      "type" : "boolean"
    },
    "BackupPolicy" : {
      "$ref" : "#/definitions/BackupPolicy",
      "description" : "Use the ``BackupPolicy`` to turn automatic backups on or off for the file system."
    },
    "AvailabilityZoneName" : {
      "type" : "string",
      "description" : "For One Zone file systems, specify the AWS Availability Zone in which to create the file system. Use the format ``us-east-1a`` to specify the Availability Zone. For more information about One Zone file systems, see [EFS file system types](https://docs.aws.amazon.com/efs/latest/ug/availability-durability.html#file-system-type) in the *Amazon EFS User Guide*.\n  One Zone file systems are not available in all Availability Zones in AWS-Regions where Amazon EFS is available."
    },
    "ReplicationConfiguration" : {
      "$ref" : "#/definitions/ReplicationConfiguration",
      "description" : "Describes the replication configuration for a specific file system."
    }
  },
  "additionalProperties" : False,
  "readOnlyProperties" : [ "/properties/Arn", "/properties/FileSystemId", "/properties/ReplicationConfiguration/Destinations/*/Status", "/properties/ReplicationConfiguration/Destinations/*/StatusMessage" ],
  "primaryIdentifier" : [ "/properties/FileSystemId" ],
  "writeOnlyProperties" : [ "/properties/BypassPolicyLockoutSafetyCheck", "/properties/ReplicationConfiguration/Destinations/0/AvailabilityZoneName", "/properties/ReplicationConfiguration/Destinations/0/KmsKeyId" ],
  "createOnlyProperties" : [ "/properties/AvailabilityZoneName", "/properties/Encrypted", "/properties/KmsKeyId", "/properties/PerformanceMode" ],
  "propertyTransform" : {
    "/properties/KmsKeyId" : "\"arn:aws[-a-z]*:kms:[a-z0-9-]+:[0-9]{12}:key/[a-zA-Z0-9-]+\"",
    "/properties/FileSystemProtection/ReplicationOverwriteProtection" : "$uppercase(FileSystemProtection.ReplicationOverwriteProtection)='DISABLED' ? 'REPLICATING' : $uppercase(FileSystemProtection.ReplicationOverwriteProtection)",
    "/properties/ReplicationConfiguration/Destinations/*/FileSystemId" : "$split(FileSystemId, \"/\")[-1]"
  },
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : True,
    "tagProperty" : "/properties/FileSystemTags",
    "permissions" : [ "elasticfilesystem:TagResource", "elasticfilesystem:ListTagsForResource", "elasticfilesystem:UntagResource", "elasticfilesystem:DeleteTags" ]
  },
  "handlers" : {
    "create" : {
      "permissions" : [ "elasticfilesystem:CreateFileSystem", "elasticfilesystem:DescribeReplicationConfigurations", "elasticfilesystem:TagResource", "elasticfilesystem:CreateReplicationConfiguration", "elasticfilesystem:DescribeFileSystems", "elasticfilesystem:PutBackupPolicy", "elasticfilesystem:PutFileSystemPolicy", "elasticfilesystem:PutLifecycleConfiguration", "elasticfilesystem:UpdateFileSystemProtection", "kms:DescribeKey", "kms:GenerateDataKeyWithoutPlaintext", "kms:CreateGrant", "iam:PassRole", "iam:CreateServiceLinkedRole" ]
    },
    "read" : {
      "permissions" : [ "elasticfilesystem:DescribeBackupPolicy", "elasticfilesystem:DescribeFileSystemPolicy", "elasticfilesystem:DescribeFileSystems", "elasticfilesystem:DescribeLifecycleConfiguration", "elasticfilesystem:DescribeReplicationConfigurations" ]
    },
    "update" : {
      "permissions" : [ "elasticfilesystem:CreateReplicationConfiguration", "elasticfilesystem:DeleteFileSystemPolicy", "elasticfilesystem:DescribeBackupPolicy", "elasticfilesystem:DescribeFileSystemPolicy", "elasticfilesystem:DescribeFileSystems", "elasticfilesystem:DescribeLifecycleConfiguration", "elasticfilesystem:DescribeReplicationConfigurations", "elasticfilesystem:DeleteTags", "elasticfilesystem:DeleteReplicationConfiguration", "elasticfilesystem:ListTagsForResource", "elasticfilesystem:PutBackupPolicy", "elasticfilesystem:PutFileSystemPolicy", "elasticfilesystem:PutLifecycleConfiguration", "elasticfilesystem:TagResource", "elasticfilesystem:UntagResource", "elasticfilesystem:UpdateFileSystem", "elasticfilesystem:UpdateFileSystemProtection", "kms:DescribeKey", "kms:GenerateDataKeyWithoutPlaintext", "kms:CreateGrant", "iam:PassRole", "iam:CreateServiceLinkedRole" ]
    },
    "delete" : {
      "permissions" : [ "elasticfilesystem:DescribeFileSystems", "elasticfilesystem:DeleteFileSystem", "elasticfilesystem:DeleteReplicationConfiguration", "elasticfilesystem:DescribeReplicationConfigurations" ]
    },
    "list" : {
      "permissions" : [ "elasticfilesystem:DescribeBackupPolicy", "elasticfilesystem:DescribeFileSystemPolicy", "elasticfilesystem:DescribeFileSystems", "elasticfilesystem:DescribeLifecycleConfiguration", "elasticfilesystem:DescribeReplicationConfigurations" ]
    }
  }
}