SCHEMA = {
  "$schema" : "https://schema.cloudformation.us-east-1.amazonaws.com/provider.definition.schema.v1.json",
  "typeName" : "AWS::GameLift::Fleet",
  "description" : "The AWS::GameLift::Fleet resource creates an Amazon GameLift (GameLift) fleet to host game servers. A fleet is a set of EC2 or Anywhere instances, each of which can host multiple game sessions.",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-gamelift.git",
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : False,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "gamelift:ListTagsForResource", "gamelift:TagResource", "gamelift:UntagResource" ]
  },
  "definitions" : {
    "AnywhereConfiguration" : {
      "description" : "Configuration for Anywhere fleet.",
      "properties" : {
        "Cost" : {
          "description" : "Cost of compute can be specified on Anywhere Fleets to prioritize placement across Queue destinations based on Cost.",
          "type" : "string",
          "pattern" : "^\\d{1,5}(?:\\.\\d{1,5})?$",
          "minLength" : 1,
          "maxLength" : 11
        }
      },
      "additionalProperties" : False,
      "required" : [ "Cost" ]
    },
    "CertificateConfiguration" : {
      "description" : "Information about the use of a TLS/SSL certificate for a fleet. TLS certificate generation is enabled at the fleet level, with one certificate generated for the fleet. When this feature is enabled, the certificate can be retrieved using the GameLift Server SDK call GetInstanceCertificate. All instances in a fleet share the same certificate.",
      "type" : "object",
      "properties" : {
        "CertificateType" : {
          "type" : "string",
          "enum" : [ "DISABLED", "GENERATED" ]
        }
      },
      "additionalProperties" : False,
      "required" : [ "CertificateType" ]
    },
    "IpPermission" : {
      "description" : "A range of IP addresses and port settings that allow inbound traffic to connect to server processes on an Amazon GameLift hosting resource. New game sessions that are started on the fleet are assigned an IP address/port number combination, which must fall into the fleet's allowed ranges. For fleets created with a custom game server, the ranges reflect the server's game session assignments. For Realtime Servers fleets, Amazon GameLift automatically opens two port ranges, one for TCP messaging and one for UDP, for use by the Realtime servers.",
      "type" : "object",
      "properties" : {
        "FromPort" : {
          "description" : "A starting value for a range of allowed port numbers.",
          "type" : "integer",
          "minimum" : 1,
          "maximum" : 60000
        },
        "IpRange" : {
          "description" : "A range of allowed IP addresses. This value must be expressed in CIDR notation. Example: \"000.000.000.000/[subnet mask]\" or optionally the shortened version \"0.0.0.0/[subnet mask]\".",
          "type" : "string",
          "pattern" : "(^(([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])\\.){3}([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])(/([0-9]|[1-2][0-9]|3[0-2]))$)"
        },
        "Protocol" : {
          "description" : "The network communication protocol used by the fleet.",
          "type" : "string",
          "enum" : [ "TCP", "UDP" ]
        },
        "ToPort" : {
          "description" : "An ending value for a range of allowed port numbers. Port numbers are end-inclusive. This value must be higher than FromPort.",
          "type" : "integer",
          "minimum" : 1,
          "maximum" : 60000
        }
      },
      "additionalProperties" : False,
      "required" : [ "FromPort", "IpRange", "Protocol", "ToPort" ]
    },
    "Location" : {
      "type" : "string",
      "minLength" : 1,
      "maxLength" : 64,
      "pattern" : "^[A-Za-z0-9\\-]+"
    },
    "LocationCapacity" : {
      "description" : "Current resource capacity settings in a specified fleet or location. The location value might refer to a fleet's remote location or its home Region.",
      "type" : "object",
      "properties" : {
        "DesiredEC2Instances" : {
          "description" : "The number of EC2 instances you want to maintain in the specified fleet location. This value must fall between the minimum and maximum size limits.",
          "type" : "integer",
          "minimum" : 0
        },
        "MinSize" : {
          "description" : "The minimum value allowed for the fleet's instance count for a location. When creating a new fleet, GameLift automatically sets this value to \"0\". After the fleet is active, you can change this value.",
          "type" : "integer",
          "minimum" : 0
        },
        "MaxSize" : {
          "description" : "The maximum value that is allowed for the fleet's instance count for a location. When creating a new fleet, GameLift automatically sets this value to \"1\". Once the fleet is active, you can change this value.",
          "type" : "integer",
          "minimum" : 0
        }
      },
      "additionalProperties" : False,
      "required" : [ "DesiredEC2Instances", "MinSize", "MaxSize" ]
    },
    "LocationConfiguration" : {
      "description" : "A remote location where a multi-location fleet can deploy EC2 instances for game hosting.",
      "type" : "object",
      "properties" : {
        "Location" : {
          "$ref" : "#/definitions/Location"
        },
        "LocationCapacity" : {
          "$ref" : "#/definitions/LocationCapacity"
        }
      },
      "additionalProperties" : False,
      "required" : [ "Location" ]
    },
    "ResourceCreationLimitPolicy" : {
      "description" : "A policy that limits the number of game sessions a player can create on the same fleet. This optional policy gives game owners control over how players can consume available game server resources. A resource creation policy makes the following statement: \"An individual player can create a maximum number of new game sessions within a specified time period\".\n\nThe policy is evaluated when a player tries to create a new game session. For example, assume you have a policy of 10 new game sessions and a time period of 60 minutes. On receiving a CreateGameSession request, Amazon GameLift checks that the player (identified by CreatorId) has created fewer than 10 game sessions in the past 60 minutes.",
      "type" : "object",
      "properties" : {
        "NewGameSessionsPerCreator" : {
          "description" : "The maximum number of game sessions that an individual can create during the policy period.",
          "type" : "integer",
          "minimum" : 0
        },
        "PolicyPeriodInMinutes" : {
          "description" : "The time span used in evaluating the resource creation limit policy.",
          "type" : "integer",
          "minimum" : 0
        }
      },
      "additionalProperties" : False
    },
    "RuntimeConfiguration" : {
      "description" : "A collection of server process configurations that describe the processes to run on each instance in a fleet. All fleets must have a runtime configuration. Each instance in the fleet maintains server processes as specified in the runtime configuration, launching new ones as existing processes end. Each instance regularly checks for an updated runtime configuration makes adjustments as called for.\n\nThe runtime configuration enables the instances in a fleet to run multiple processes simultaneously. Potential scenarios are as follows: (1) Run multiple processes of a single game server executable to maximize usage of your hosting resources. (2) Run one or more processes of different executables, such as your game server and a metrics tracking program. (3) Run multiple processes of a single game server but with different launch parameters, for example to run one process on each instance in debug mode.\n\nAn Amazon GameLift instance is limited to 50 processes running simultaneously. A runtime configuration must specify fewer than this limit. To calculate the total number of processes specified in a runtime configuration, add the values of the ConcurrentExecutions parameter for each ServerProcess object in the runtime configuration.",
      "type" : "object",
      "properties" : {
        "GameSessionActivationTimeoutSeconds" : {
          "description" : "The maximum amount of time (in seconds) that a game session can remain in status ACTIVATING. If the game session is not active before the timeout, activation is terminated and the game session status is changed to TERMINATED.",
          "type" : "integer",
          "minimum" : 1,
          "maximum" : 600
        },
        "MaxConcurrentGameSessionActivations" : {
          "description" : "The maximum number of game sessions with status ACTIVATING to allow on an instance simultaneously. This setting limits the amount of instance resources that can be used for new game activations at any one time.",
          "type" : "integer",
          "minimum" : 1,
          "maximum" : 2147483647
        },
        "ServerProcesses" : {
          "description" : "A collection of server process configurations that describe which server processes to run on each instance in a fleet.",
          "type" : "array",
          "maxItems" : 50,
          "items" : {
            "$ref" : "#/definitions/ServerProcess"
          },
          "insertionOrder" : False
        }
      },
      "additionalProperties" : False
    },
    "ScalingPolicy" : {
      "description" : "Rule that controls how a fleet is scaled. Scaling policies are uniquely identified by the combination of name and fleet ID.",
      "type" : "object",
      "properties" : {
        "ComparisonOperator" : {
          "description" : "Comparison operator to use when measuring a metric against the threshold value.",
          "type" : "string",
          "enum" : [ "GreaterThanOrEqualToThreshold", "GreaterThanThreshold", "LessThanThreshold", "LessThanOrEqualToThreshold" ]
        },
        "EvaluationPeriods" : {
          "description" : "Length of time (in minutes) the metric must be at or beyond the threshold before a scaling event is triggered.",
          "type" : "integer",
          "minimum" : 1
        },
        "Location" : {
          "$ref" : "#/definitions/Location"
        },
        "MetricName" : {
          "description" : "Name of the Amazon GameLift-defined metric that is used to trigger a scaling adjustment.",
          "type" : "string",
          "enum" : [ "ActivatingGameSessions", "ActiveGameSessions", "ActiveInstances", "AvailableGameSessions", "AvailablePlayerSessions", "CurrentPlayerSessions", "IdleInstances", "PercentAvailableGameSessions", "PercentIdleInstances", "QueueDepth", "WaitTime", "ConcurrentActivatableGameSessions" ]
        },
        "Name" : {
          "description" : "A descriptive label that is associated with a fleet's scaling policy. Policy names do not need to be unique.",
          "type" : "string",
          "minLength" : 1,
          "maxLength" : 1024
        },
        "PolicyType" : {
          "description" : "The type of scaling policy to create. For a target-based policy, set the parameter MetricName to 'PercentAvailableGameSessions' and specify a TargetConfiguration. For a rule-based policy set the following parameters: MetricName, ComparisonOperator, Threshold, EvaluationPeriods, ScalingAdjustmentType, and ScalingAdjustment.",
          "type" : "string",
          "enum" : [ "RuleBased", "TargetBased" ]
        },
        "ScalingAdjustment" : {
          "description" : "Amount of adjustment to make, based on the scaling adjustment type.",
          "type" : "integer"
        },
        "ScalingAdjustmentType" : {
          "description" : "The type of adjustment to make to a fleet's instance count.",
          "type" : "string",
          "enum" : [ "ChangeInCapacity", "ExactCapacity", "PercentChangeInCapacity" ]
        },
        "Status" : {
          "description" : "Current status of the scaling policy. The scaling policy can be in force only when in an ACTIVE status. Scaling policies can be suspended for individual fleets. If the policy is suspended for a fleet, the policy status does not change.",
          "type" : "string",
          "enum" : [ "ACTIVE", "UPDATE_REQUESTED", "UPDATING", "DELETE_REQUESTED", "DELETING", "DELETED", "ERROR" ]
        },
        "TargetConfiguration" : {
          "description" : "An object that contains settings for a target-based scaling policy.",
          "$ref" : "#/definitions/TargetConfiguration"
        },
        "Threshold" : {
          "description" : "Metric value used to trigger a scaling event.",
          "type" : "number"
        },
        "UpdateStatus" : {
          "description" : "The current status of the fleet's scaling policies in a requested fleet location. The status PENDING_UPDATE indicates that an update was requested for the fleet but has not yet been completed for the location.",
          "type" : "string",
          "enum" : [ "PENDING_UPDATE" ]
        }
      },
      "additionalProperties" : False,
      "required" : [ "MetricName", "Name" ]
    },
    "ServerProcess" : {
      "description" : "A set of instructions for launching server processes on each instance in a fleet. Each instruction set identifies the location of the server executable, optional launch parameters, and the number of server processes with this configuration to maintain concurrently on the instance. Server process configurations make up a fleet's RuntimeConfiguration.",
      "type" : "object",
      "properties" : {
        "ConcurrentExecutions" : {
          "description" : "The number of server processes that use this configuration to run concurrently on an instance.",
          "type" : "integer",
          "minimum" : 1
        },
        "LaunchPath" : {
          "description" : "The location of the server executable in a custom game build or the name of the Realtime script file that contains the Init() function. Game builds and Realtime scripts are installed on instances at the root:\n\nWindows (for custom game builds only): C:\\game. Example: \"C:\\game\\MyGame\\server.exe\"\n\nLinux: /local/game. Examples: \"/local/game/MyGame/server.exe\" or \"/local/game/MyRealtimeScript.js\"",
          "type" : "string",
          "minLength" : 1,
          "maxLength" : 1024,
          "pattern" : "^([Cc]:\\\\game\\S+|/local/game/\\S+)"
        },
        "Parameters" : {
          "description" : "An optional list of parameters to pass to the server executable or Realtime script on launch.",
          "type" : "string",
          "minLength" : 1,
          "maxLength" : 1024
        }
      },
      "additionalProperties" : False,
      "required" : [ "ConcurrentExecutions", "LaunchPath" ]
    },
    "Tag" : {
      "description" : "A key-value pair to associate with a resource.",
      "type" : "object",
      "properties" : {
        "Key" : {
          "type" : "string",
          "description" : "The key name of the tag. You can specify a value that is 1 to 128 Unicode characters in length.",
          "minLength" : 1,
          "maxLength" : 128
        },
        "Value" : {
          "type" : "string",
          "description" : "The value for the tag. You can specify a value that is 0 to 256 Unicode characters in length.",
          "minLength" : 0,
          "maxLength" : 256
        }
      },
      "required" : [ "Key", "Value" ],
      "additionalProperties" : False
    },
    "TargetConfiguration" : {
      "description" : "Settings for a target-based scaling policy. A target-based policy tracks a particular fleet metric specifies a target value for the metric. As player usage changes, the policy triggers Amazon GameLift to adjust capacity so that the metric returns to the target value. The target configuration specifies settings as needed for the target based policy, including the target value.",
      "type" : "object",
      "properties" : {
        "TargetValue" : {
          "description" : "Desired value to use with a target-based scaling policy. The value must be relevant for whatever metric the scaling policy is using. For example, in a policy using the metric PercentAvailableGameSessions, the target value should be the preferred size of the fleet's buffer (the percent of capacity that should be idle and ready for new game sessions).",
          "type" : "number"
        }
      },
      "additionalProperties" : False,
      "required" : [ "TargetValue" ]
    }
  },
  "properties" : {
    "ScalingPolicies" : {
      "description" : "A list of rules that control how a fleet is scaled.",
      "type" : "array",
      "maxItems" : 50,
      "items" : {
        "$ref" : "#/definitions/ScalingPolicy"
      },
      "insertionOrder" : False
    },
    "AnywhereConfiguration" : {
      "description" : "Configuration for Anywhere fleet.",
      "$ref" : "#/definitions/AnywhereConfiguration"
    },
    "ApplyCapacity" : {
      "description" : "Determines whether to apply fleet or location capacities on fleet creation.",
      "type" : "string",
      "enum" : [ "ON_UPDATE", "ON_CREATE_AND_UPDATE" ]
    },
    "CertificateConfiguration" : {
      "description" : "Indicates whether to generate a TLS/SSL certificate for the new fleet. TLS certificates are used for encrypting traffic between game clients and game servers running on GameLift. If this parameter is not set, certificate generation is disabled. This fleet setting cannot be changed once the fleet is created.",
      "$ref" : "#/definitions/CertificateConfiguration"
    },
    "ComputeType" : {
      "description" : "ComputeType to differentiate EC2 hardware managed by GameLift and Anywhere hardware managed by the customer.",
      "type" : "string",
      "enum" : [ "EC2", "ANYWHERE" ]
    },
    "Description" : {
      "description" : "A human-readable description of a fleet.",
      "type" : "string",
      "minLength" : 1,
      "maxLength" : 1024
    },
    "DesiredEC2Instances" : {
      "description" : "[DEPRECATED] The number of EC2 instances that you want this fleet to host. When creating a new fleet, GameLift automatically sets this value to \"1\" and initiates a single instance. Once the fleet is active, update this value to trigger GameLift to add or remove instances from the fleet.",
      "type" : "integer",
      "minimum" : 0
    },
    "EC2InboundPermissions" : {
      "description" : "A range of IP addresses and port settings that allow inbound traffic to connect to server processes on an Amazon GameLift server.",
      "type" : "array",
      "maxItems" : 50,
      "items" : {
        "$ref" : "#/definitions/IpPermission"
      },
      "insertionOrder" : False
    },
    "EC2InstanceType" : {
      "description" : "The name of an EC2 instance type that is supported in Amazon GameLift. A fleet instance type determines the computing resources of each instance in the fleet, including CPU, memory, storage, and networking capacity. Amazon GameLift supports the following EC2 instance types. See Amazon EC2 Instance Types for detailed descriptions.",
      "type" : "string",
      "pattern" : "^.*..*$"
    },
    "FleetType" : {
      "description" : "Indicates whether to use On-Demand instances or Spot instances for this fleet. If empty, the default is ON_DEMAND. Both categories of instances use identical hardware and configurations based on the instance type selected for this fleet.",
      "type" : "string",
      "enum" : [ "ON_DEMAND", "SPOT" ]
    },
    "InstanceRoleARN" : {
      "description" : "A unique identifier for an AWS IAM role that manages access to your AWS services. With an instance role ARN set, any application that runs on an instance in this fleet can assume the role, including install scripts, server processes, and daemons (background processes). Create a role or look up a role's ARN from the IAM dashboard in the AWS Management Console.",
      "type" : "string",
      "minLength" : 1,
      "pattern" : "^arn:aws(-.*)?:[a-z-]+:(([a-z]+-)+[0-9])?:([0-9]{12})?:[^.]+$"
    },
    "InstanceRoleCredentialsProvider" : {
      "description" : "Credentials provider implementation that loads credentials from the Amazon EC2 Instance Metadata Service.",
      "type" : "string",
      "enum" : [ "SHARED_CREDENTIAL_FILE" ]
    },
    "Locations" : {
      "type" : "array",
      "minItems" : 1,
      "maxItems" : 100,
      "items" : {
        "$ref" : "#/definitions/LocationConfiguration"
      },
      "insertionOrder" : False
    },
    "LogPaths" : {
      "description" : "This parameter is no longer used. When hosting a custom game build, specify where Amazon GameLift should store log files using the Amazon GameLift server API call ProcessReady()",
      "type" : "array",
      "items" : {
        "type" : "string"
      },
      "insertionOrder" : False
    },
    "MaxSize" : {
      "description" : "[DEPRECATED] The maximum value that is allowed for the fleet's instance count. When creating a new fleet, GameLift automatically sets this value to \"1\". Once the fleet is active, you can change this value.",
      "type" : "integer",
      "minimum" : 0
    },
    "MetricGroups" : {
      "description" : "The name of an Amazon CloudWatch metric group. A metric group aggregates the metrics for all fleets in the group. Specify a string containing the metric group name. You can use an existing name or use a new name to create a new metric group. Currently, this parameter can have only one string.",
      "type" : "array",
      "maxItems" : 1,
      "items" : {
        "type" : "string"
      },
      "insertionOrder" : False
    },
    "MinSize" : {
      "description" : "[DEPRECATED] The minimum value allowed for the fleet's instance count. When creating a new fleet, GameLift automatically sets this value to \"0\". After the fleet is active, you can change this value.",
      "type" : "integer",
      "minimum" : 0
    },
    "Name" : {
      "description" : "A descriptive label that is associated with a fleet. Fleet names do not need to be unique.",
      "type" : "string",
      "minLength" : 1,
      "maxLength" : 1024
    },
    "NewGameSessionProtectionPolicy" : {
      "description" : "A game session protection policy to apply to all game sessions hosted on instances in this fleet. When protected, active game sessions cannot be terminated during a scale-down event. If this parameter is not set, instances in this fleet default to no protection. You can change a fleet's protection policy to affect future game sessions on the fleet. You can also set protection for individual game sessions.",
      "type" : "string",
      "enum" : [ "FullProtection", "NoProtection" ]
    },
    "PeerVpcAwsAccountId" : {
      "description" : "A unique identifier for the AWS account with the VPC that you want to peer your Amazon GameLift fleet with. You can find your account ID in the AWS Management Console under account settings.",
      "type" : "string",
      "minLength" : 1,
      "maxLength" : 1024,
      "pattern" : "^[0-9]{12}$"
    },
    "PeerVpcId" : {
      "description" : "A unique identifier for a VPC with resources to be accessed by your Amazon GameLift fleet. The VPC must be in the same Region as your fleet. To look up a VPC ID, use the VPC Dashboard in the AWS Management Console.",
      "type" : "string",
      "minLength" : 1,
      "maxLength" : 1024,
      "pattern" : "^vpc-\\S+"
    },
    "ResourceCreationLimitPolicy" : {
      "description" : "A policy that limits the number of game sessions an individual player can create over a span of time for this fleet.",
      "$ref" : "#/definitions/ResourceCreationLimitPolicy"
    },
    "FleetId" : {
      "description" : "Unique fleet ID",
      "type" : "string",
      "pattern" : "^fleet-\\S+"
    },
    "BuildId" : {
      "description" : "A unique identifier for a build to be deployed on the new fleet. If you are deploying the fleet with a custom game build, you must specify this property. The build must have been successfully uploaded to Amazon GameLift and be in a READY status. This fleet setting cannot be changed once the fleet is created.",
      "type" : "string",
      "pattern" : "^build-\\S+|^arn:.*:build/build-\\S+"
    },
    "ScriptId" : {
      "description" : "A unique identifier for a Realtime script to be deployed on a new Realtime Servers fleet. The script must have been successfully uploaded to Amazon GameLift. This fleet setting cannot be changed once the fleet is created.\n\nNote: It is not currently possible to use the !Ref command to reference a script created with a CloudFormation template for the fleet property ScriptId. Instead, use Fn::GetAtt Script.Arn or Fn::GetAtt Script.Id to retrieve either of these properties as input for ScriptId. Alternatively, enter a ScriptId string manually.",
      "type" : "string",
      "pattern" : "^script-\\S+|^arn:.*:script/script-\\S+"
    },
    "RuntimeConfiguration" : {
      "description" : "Instructions for launching server processes on each instance in the fleet. Server processes run either a custom game build executable or a Realtime script. The runtime configuration defines the server executables or launch script file, launch parameters, and the number of processes to run concurrently on each instance. When creating a fleet, the runtime configuration must have at least one server process configuration; otherwise the request fails with an invalid request exception.\n\nThis parameter is required unless the parameters ServerLaunchPath and ServerLaunchParameters are defined. Runtime configuration has replaced these parameters, but fleets that use them will continue to work.",
      "$ref" : "#/definitions/RuntimeConfiguration"
    },
    "ServerLaunchParameters" : {
      "description" : "This parameter is no longer used but is retained for backward compatibility. Instead, specify server launch parameters in the RuntimeConfiguration parameter. A request must specify either a runtime configuration or values for both ServerLaunchParameters and ServerLaunchPath.",
      "type" : "string",
      "minLength" : 1,
      "maxLength" : 1024
    },
    "ServerLaunchPath" : {
      "description" : "This parameter is no longer used. Instead, specify a server launch path using the RuntimeConfiguration parameter. Requests that specify a server launch path and launch parameters instead of a runtime configuration will continue to work.",
      "type" : "string",
      "minLength" : 1,
      "maxLength" : 1024
    },
    "Tags" : {
      "description" : "An array of key-value pairs to apply to this resource.",
      "type" : "array",
      "uniqueItems" : True,
      "insertionOrder" : False,
      "maxItems" : 200,
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    },
    "FleetArn" : {
      "description" : "The Amazon Resource Name (ARN) that is assigned to a Amazon GameLift Servers Fleet resource and uniquely identifies it. ARNs are unique across all Regions. In a GameLift Fleet ARN, the resource ID matches the FleetId value.",
      "pattern" : "^arn:.*:fleet/[a-z]*fleet-[a-zA-Z0-9\\-]+$",
      "type" : "string"
    }
  },
  "required" : [ "Name" ],
  "additionalProperties" : False,
  "createOnlyProperties" : [ "/properties/ApplyCapacity", "/properties/BuildId", "/properties/CertificateConfiguration", "/properties/EC2InstanceType", "/properties/FleetType", "/properties/InstanceRoleARN", "/properties/InstanceRoleCredentialsProvider", "/properties/LogPaths", "/properties/PeerVpcAwsAccountId", "/properties/PeerVpcId", "/properties/ScriptId", "/properties/ServerLaunchParameters", "/properties/ServerLaunchPath", "/properties/ComputeType" ],
  "deprecatedProperties" : [ "/properties/LogPaths", "/properties/ServerLaunchParameters", "/properties/ServerLaunchPath", "/properties/MinSize", "/properties/MaxSize", "/properties/DesiredEC2Instances" ],
  "readOnlyProperties" : [ "/properties/FleetId", "/properties/FleetArn" ],
  "writeOnlyProperties" : [ "/properties/ApplyCapacity" ],
  "primaryIdentifier" : [ "/properties/FleetId" ],
  "propertyTransform" : {
    "/properties/AnywhereConfiguration/Cost" : "$contains(Cost, \".\") ? Cost : Cost & \".0\""
  },
  "handlers" : {
    "create" : {
      "permissions" : [ "gamelift:CreateFleet", "gamelift:CreateFleetLocations", "gamelift:DescribeFleetAttributes", "gamelift:DescribeFleetLocationAttributes", "gamelift:UpdateFleetCapacity", "gamelift:DescribeFleetLocationCapacity", "gamelift:DescribeFleetCapacity", "gamelift:DescribeFleetPortSettings", "gamelift:DescribeRuntimeConfiguration", "gamelift:PutScalingPolicy", "gamelift:DescribeScalingPolicies", "gamelift:ListTagsForResource", "gamelift:UpdateFleetCapacity", "gamelift:TagResource" ]
    },
    "read" : {
      "permissions" : [ "gamelift:DescribeFleetAttributes", "gamelift:DescribeFleetLocationAttributes", "gamelift:DescribeFleetLocationCapacity", "gamelift:DescribeFleetCapacity", "gamelift:DescribeFleetPortSettings", "gamelift:DescribeRuntimeConfiguration", "gamelift:DescribeScalingPolicies", "gamelift:ListTagsForResource" ]
    },
    "update" : {
      "permissions" : [ "gamelift:UpdateFleetAttributes", "gamelift:CreateFleetLocations", "gamelift:DeleteFleetLocations", "gamelift:UpdateFleetCapacity", "gamelift:UpdateFleetPortSettings", "gamelift:UpdateRuntimeConfiguration", "gamelift:DescribeFleetLocationCapacity", "gamelift:DescribeFleetPortSettings", "gamelift:DescribeFleetLocationAttributes", "gamelift:PutScalingPolicy", "gamelift:DescribeScalingPolicies", "gamelift:DeleteScalingPolicy", "gamelift:DescribeFleetAttributes", "gamelift:DescribeFleetCapacity", "gamelift:DescribeRuntimeConfiguration", "gamelift:TagResource", "gamelift:UntagResource", "gamelift:ListTagsForResource" ]
    },
    "delete" : {
      "permissions" : [ "gamelift:DeleteFleet", "gamelift:DescribeFleetLocationCapacity", "gamelift:DescribeFleetAttributes", "gamelift:DescribeFleetCapacity", "gamelift:DescribeFleetLocationCapacity", "gamelift:UpdateFleetCapacity", "gamelift:DescribeScalingPolicies", "gamelift:DeleteScalingPolicy" ]
    },
    "list" : {
      "permissions" : [ "gamelift:ListFleets" ]
    }
  }
}