SCHEMA = {
  "typeName" : "AWS::Logs::Transformer",
  "description" : "Specifies a transformer on the log group to transform logs into consistent structured and information rich format.",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-logs.git",
  "properties" : {
    "LogGroupIdentifier" : {
      "description" : "Existing log group that you want to associate with this transformer.",
      "type" : "string",
      "minLength" : 1,
      "maxLength" : 2048,
      "pattern" : "[\\w#+=/:,.@-]*"
    },
    "TransformerConfig" : {
      "description" : "List of processors in a transformer",
      "type" : "array",
      "items" : {
        "$ref" : "#/definitions/Processor"
      },
      "minItems" : 1,
      "maxItems" : 20,
      "insertionOrder" : False
    }
  },
  "required" : [ "LogGroupIdentifier", "TransformerConfig" ],
  "additionalProperties" : False,
  "definitions" : {
    "Processor" : {
      "description" : "Individual processor configuration",
      "type" : "object",
      "properties" : {
        "ParseCloudfront" : {
          "$ref" : "#/definitions/ParseCloudfront"
        },
        "ParseVPC" : {
          "$ref" : "#/definitions/ParseVPC"
        },
        "ParseWAF" : {
          "$ref" : "#/definitions/ParseWAF"
        },
        "ParseJSON" : {
          "type" : "object",
          "properties" : {
            "Source" : {
              "type" : "string"
            },
            "Destination" : {
              "$ref" : "#/definitions/NonEmptyAndMaxLengthString"
            }
          },
          "additionalProperties" : False
        },
        "ParseRoute53" : {
          "$ref" : "#/definitions/ParseRoute53"
        },
        "ParsePostgres" : {
          "$ref" : "#/definitions/ParsePostgres"
        },
        "ParseKeyValue" : {
          "type" : "object",
          "properties" : {
            "Source" : {
              "$ref" : "#/definitions/NonEmptyString"
            },
            "Destination" : {
              "$ref" : "#/definitions/NonEmptyString"
            },
            "FieldDelimiter" : {
              "type" : "string"
            },
            "KeyValueDelimiter" : {
              "type" : "string"
            },
            "KeyPrefix" : {
              "$ref" : "#/definitions/NonEmptyString"
            },
            "NonMatchValue" : {
              "$ref" : "#/definitions/NonEmptyString"
            },
            "OverwriteIfExists" : {
              "type" : "boolean"
            }
          },
          "additionalProperties" : False
        },
        "CopyValue" : {
          "type" : "object",
          "properties" : {
            "Entries" : {
              "type" : "array",
              "items" : {
                "$ref" : "#/definitions/CopyValueEntry"
              },
              "minItems" : 1,
              "maxItems" : 5,
              "insertionOrder" : False
            }
          },
          "required" : [ "Entries" ],
          "additionalProperties" : False
        },
        "Csv" : {
          "type" : "object",
          "properties" : {
            "QuoteCharacter" : {
              "type" : "string",
              "maxLength" : 1
            },
            "Delimiter" : {
              "type" : "string",
              "maxLength" : 2
            },
            "Source" : {
              "type" : "string"
            },
            "Columns" : {
              "type" : "array",
              "items" : {
                "$ref" : "#/definitions/Column"
              },
              "minItems" : 1,
              "maxItems" : 100,
              "insertionOrder" : False
            }
          },
          "additionalProperties" : False
        },
        "DateTimeConverter" : {
          "type" : "object",
          "properties" : {
            "Source" : {
              "$ref" : "#/definitions/NonEmptyString"
            },
            "Target" : {
              "$ref" : "#/definitions/NonEmptyAndMaxLengthString"
            },
            "TargetFormat" : {
              "type" : "string"
            },
            "MatchPatterns" : {
              "type" : "array",
              "items" : {
                "$ref" : "#/definitions/MatchPattern"
              },
              "minItems" : 1,
              "maxItems" : 5,
              "uniqueItems" : True,
              "insertionOrder" : False
            },
            "SourceTimezone" : {
              "type" : "string"
            },
            "TargetTimezone" : {
              "type" : "string"
            },
            "Locale" : {
              "type" : "string"
            }
          },
          "required" : [ "Source", "Target", "MatchPatterns" ],
          "additionalProperties" : False
        },
        "DeleteKeys" : {
          "type" : "object",
          "properties" : {
            "WithKeys" : {
              "type" : "array",
              "items" : {
                "$ref" : "#/definitions/WithKey"
              },
              "minItems" : 1,
              "maxItems" : 5,
              "uniqueItems" : True,
              "insertionOrder" : False
            }
          },
          "required" : [ "WithKeys" ],
          "additionalProperties" : False
        },
        "Grok" : {
          "type" : "object",
          "properties" : {
            "Source" : {
              "$ref" : "#/definitions/NonEmptyString"
            },
            "Match" : {
              "type" : "string",
              "maxLength" : 512
            }
          },
          "required" : [ "Match" ],
          "additionalProperties" : False
        },
        "ListToMap" : {
          "type" : "object",
          "properties" : {
            "Source" : {
              "$ref" : "#/definitions/NonEmptyString"
            },
            "Key" : {
              "$ref" : "#/definitions/NonEmptyString"
            },
            "ValueKey" : {
              "$ref" : "#/definitions/NonEmptyString"
            },
            "Target" : {
              "$ref" : "#/definitions/NonEmptyAndMaxLengthString"
            },
            "Flatten" : {
              "type" : "boolean"
            },
            "FlattenedElement" : {
              "type" : "string",
              "enum" : [ "first", "last" ]
            }
          },
          "required" : [ "Source", "Key" ],
          "additionalProperties" : False
        },
        "AddKeys" : {
          "type" : "object",
          "properties" : {
            "Entries" : {
              "type" : "array",
              "items" : {
                "$ref" : "#/definitions/AddKeyEntry"
              },
              "minItems" : 1,
              "maxItems" : 5,
              "uniqueItems" : True,
              "insertionOrder" : False
            }
          },
          "required" : [ "Entries" ],
          "additionalProperties" : False
        },
        "MoveKeys" : {
          "type" : "object",
          "properties" : {
            "Entries" : {
              "type" : "array",
              "items" : {
                "$ref" : "#/definitions/MoveKeyEntry"
              },
              "minItems" : 1,
              "maxItems" : 5,
              "insertionOrder" : False
            }
          },
          "required" : [ "Entries" ],
          "additionalProperties" : False
        },
        "RenameKeys" : {
          "type" : "object",
          "properties" : {
            "Entries" : {
              "type" : "array",
              "items" : {
                "$ref" : "#/definitions/RenameKeyEntry"
              },
              "minItems" : 1,
              "maxItems" : 5,
              "insertionOrder" : False
            }
          },
          "required" : [ "Entries" ],
          "additionalProperties" : False
        },
        "LowerCaseString" : {
          "type" : "object",
          "properties" : {
            "WithKeys" : {
              "type" : "array",
              "items" : {
                "$ref" : "#/definitions/WithKey"
              },
              "minItems" : 1,
              "maxItems" : 10,
              "uniqueItems" : True,
              "insertionOrder" : False
            }
          },
          "required" : [ "WithKeys" ],
          "additionalProperties" : False
        },
        "SplitString" : {
          "type" : "object",
          "properties" : {
            "Entries" : {
              "type" : "array",
              "items" : {
                "$ref" : "#/definitions/SplitStringEntry"
              },
              "minItems" : 1,
              "maxItems" : 10,
              "insertionOrder" : False
            }
          },
          "required" : [ "Entries" ],
          "additionalProperties" : False
        },
        "SubstituteString" : {
          "type" : "object",
          "properties" : {
            "Entries" : {
              "type" : "array",
              "items" : {
                "$ref" : "#/definitions/SubstituteStringEntry"
              },
              "minItems" : 1,
              "maxItems" : 10,
              "insertionOrder" : False
            }
          },
          "required" : [ "Entries" ],
          "additionalProperties" : False
        },
        "TrimString" : {
          "type" : "object",
          "properties" : {
            "WithKeys" : {
              "type" : "array",
              "items" : {
                "$ref" : "#/definitions/WithKey"
              },
              "minItems" : 1,
              "maxItems" : 10,
              "uniqueItems" : True,
              "insertionOrder" : False
            }
          },
          "required" : [ "WithKeys" ],
          "additionalProperties" : False
        },
        "UpperCaseString" : {
          "type" : "object",
          "properties" : {
            "WithKeys" : {
              "type" : "array",
              "items" : {
                "$ref" : "#/definitions/WithKey"
              },
              "minItems" : 1,
              "maxItems" : 10,
              "uniqueItems" : True,
              "insertionOrder" : False
            }
          },
          "required" : [ "WithKeys" ],
          "additionalProperties" : False
        },
        "TypeConverter" : {
          "type" : "object",
          "properties" : {
            "Entries" : {
              "type" : "array",
              "items" : {
                "$ref" : "#/definitions/TypeConverterEntry"
              },
              "minItems" : 1,
              "maxItems" : 5,
              "insertionOrder" : False
            }
          },
          "required" : [ "Entries" ],
          "additionalProperties" : False
        }
      },
      "additionalProperties" : False,
      "minProperties" : 1,
      "maxProperties" : 1
    },
    "ParseCloudfront" : {
      "type" : "object",
      "properties" : {
        "Source" : {
          "$ref" : "#/definitions/NonEmptyString"
        }
      },
      "additionalProperties" : False
    },
    "ParseVPC" : {
      "type" : "object",
      "properties" : {
        "Source" : {
          "$ref" : "#/definitions/NonEmptyString"
        }
      },
      "additionalProperties" : False
    },
    "ParseWAF" : {
      "type" : "object",
      "properties" : {
        "Source" : {
          "$ref" : "#/definitions/NonEmptyString"
        }
      },
      "additionalProperties" : False
    },
    "ParseRoute53" : {
      "type" : "object",
      "properties" : {
        "Source" : {
          "$ref" : "#/definitions/NonEmptyString"
        }
      },
      "additionalProperties" : False
    },
    "ParsePostgres" : {
      "type" : "object",
      "properties" : {
        "Source" : {
          "$ref" : "#/definitions/NonEmptyString"
        }
      },
      "additionalProperties" : False
    },
    "AddKeyEntry" : {
      "type" : "object",
      "properties" : {
        "Key" : {
          "$ref" : "#/definitions/NonEmptyAndMaxLengthString"
        },
        "Value" : {
          "type" : "string",
          "minLength" : 1,
          "maxLength" : 256
        },
        "OverwriteIfExists" : {
          "type" : "boolean"
        }
      },
      "additionalProperties" : False,
      "required" : [ "Key", "Value" ]
    },
    "CopyValueEntry" : {
      "type" : "object",
      "properties" : {
        "Source" : {
          "$ref" : "#/definitions/NonEmptyString"
        },
        "Target" : {
          "$ref" : "#/definitions/NonEmptyAndMaxLengthString"
        },
        "OverwriteIfExists" : {
          "type" : "boolean"
        }
      },
      "required" : [ "Source", "Target" ],
      "additionalProperties" : False
    },
    "Column" : {
      "$ref" : "#/definitions/NonEmptyAndMaxLengthString"
    },
    "WithKey" : {
      "type" : "string",
      "minLength" : 1,
      "maxLength" : 128
    },
    "MatchPattern" : {
      "$ref" : "#/definitions/NonEmptyString"
    },
    "MoveKeyEntry" : {
      "type" : "object",
      "properties" : {
        "Source" : {
          "$ref" : "#/definitions/NonEmptyString"
        },
        "Target" : {
          "$ref" : "#/definitions/NonEmptyString"
        },
        "OverwriteIfExists" : {
          "type" : "boolean"
        }
      },
      "required" : [ "Source", "Target" ],
      "additionalProperties" : False
    },
    "RenameKeyEntry" : {
      "type" : "object",
      "properties" : {
        "Key" : {
          "$ref" : "#/definitions/NonEmptyString"
        },
        "RenameTo" : {
          "$ref" : "#/definitions/NonEmptyString"
        },
        "OverwriteIfExists" : {
          "type" : "boolean"
        }
      },
      "required" : [ "Key", "RenameTo" ],
      "additionalProperties" : False
    },
    "SplitStringEntry" : {
      "type" : "object",
      "properties" : {
        "Source" : {
          "$ref" : "#/definitions/NonEmptyString"
        },
        "Delimiter" : {
          "type" : "string",
          "maxLength" : 128
        }
      },
      "required" : [ "Source", "Delimiter" ],
      "additionalProperties" : False
    },
    "SubstituteStringEntry" : {
      "type" : "object",
      "properties" : {
        "Source" : {
          "$ref" : "#/definitions/NonEmptyString"
        },
        "From" : {
          "$ref" : "#/definitions/NonEmptyAndMaxLengthString"
        },
        "To" : {
          "$ref" : "#/definitions/NonEmptyAndMaxLengthString"
        }
      },
      "required" : [ "Source", "From", "To" ],
      "additionalProperties" : False
    },
    "TypeConverterEntry" : {
      "type" : "object",
      "properties" : {
        "Key" : {
          "$ref" : "#/definitions/NonEmptyString"
        },
        "Type" : {
          "type" : "string",
          "enum" : [ "boolean", "integer", "double", "string" ]
        }
      },
      "required" : [ "Key", "Type" ],
      "additionalProperties" : False
    },
    "NonEmptyAndMaxLengthString" : {
      "type" : "string",
      "maxLength" : 128,
      "pattern" : "^.*[a-zA-Z0-9]+.*$"
    },
    "NonEmptyString" : {
      "type" : "string",
      "pattern" : "^.*[a-zA-Z0-9]+.*$"
    },
    "MaxLengthString" : {
      "type" : "string",
      "maxLength" : 128
    }
  },
  "primaryIdentifier" : [ "/properties/LogGroupIdentifier" ],
  "createOnlyProperties" : [ "/properties/LogGroupIdentifier" ],
  "handlers" : {
    "create" : {
      "permissions" : [ "logs:PutTransformer", "logs:GetTransformer" ]
    },
    "read" : {
      "permissions" : [ "logs:GetTransformer" ]
    },
    "update" : {
      "permissions" : [ "logs:GetTransformer", "logs:PutTransformer" ]
    },
    "delete" : {
      "permissions" : [ "logs:DeleteTransformer" ]
    },
    "list" : {
      "permissions" : [ "logs:DescribeLogGroups", "logs:GetTransformer" ]
    }
  },
  "tagging" : {
    "taggable" : False,
    "tagOnCreate" : False,
    "tagUpdatable" : False,
    "cloudFormationSystemTags" : False
  }
}