SCHEMA = {
  "typeName" : "AWS::RDS::DBClusterParameterGroup",
  "description" : "The ``AWS::RDS::DBClusterParameterGroup`` resource creates a new Amazon RDS DB cluster parameter group.\n For information about configuring parameters for Amazon Aurora DB clusters, see [Working with parameter groups](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/USER_WorkingWithParamGroups.html) in the *Amazon Aurora User Guide*.\n  If you apply a parameter group to a DB cluster, then its DB instances might need to reboot. This can result in an outage while the DB instances are rebooting.\n If you apply a change to parameter group associated with a stopped DB cluster, then the updated stack waits until the DB cluster is started.",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-rds",
  "definitions" : {
    "Tag" : {
      "description" : "Metadata assigned to an Amazon RDS resource consisting of a key-value pair.\n For more information, see [Tagging Amazon RDS resources](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_Tagging.html) in the *Amazon RDS User Guide* or [Tagging Amazon Aurora and Amazon RDS resources](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/USER_Tagging.html) in the *Amazon Aurora User Guide*.",
      "type" : "object",
      "properties" : {
        "Key" : {
          "type" : "string",
          "description" : "A key is the required name of the tag. The string value can be from 1 to 128 Unicode characters in length and can't be prefixed with ``aws:`` or ``rds:``. The string can only contain only the set of Unicode letters, digits, white-space, '_', '.', ':', '/', '=', '+', '-', '@' (Java regex: \"^([\\\\p{L}\\\\p{Z}\\\\p{N}_.:/=+\\\\-@]*)$\").",
          "minLength" : 1,
          "maxLength" : 128
        },
        "Value" : {
          "type" : "string",
          "description" : "A value is the optional value of the tag. The string value can be from 1 to 256 Unicode characters in length and can't be prefixed with ``aws:`` or ``rds:``. The string can only contain only the set of Unicode letters, digits, white-space, '_', '.', ':', '/', '=', '+', '-', '@' (Java regex: \"^([\\\\p{L}\\\\p{Z}\\\\p{N}_.:/=+\\\\-@]*)$\").",
          "minLength" : 0,
          "maxLength" : 256
        }
      },
      "required" : [ "Key" ],
      "additionalProperties" : False
    }
  },
  "properties" : {
    "Description" : {
      "description" : "The description for the DB cluster parameter group.",
      "type" : "string"
    },
    "Family" : {
      "description" : "The DB cluster parameter group family name. A DB cluster parameter group can be associated with one and only one DB cluster parameter group family, and can be applied only to a DB cluster running a database engine and engine version compatible with that DB cluster parameter group family.\n  *Aurora MySQL* \n Example: ``aurora-mysql5.7``, ``aurora-mysql8.0``\n  *Aurora PostgreSQL* \n Example: ``aurora-postgresql14``\n  *RDS for MySQL* \n Example: ``mysql8.0``\n  *RDS for PostgreSQL* \n Example: ``postgres13``\n To list all of the available parameter group families for a DB engine, use the following command:\n  ``aws rds describe-db-engine-versions --query \"DBEngineVersions[].DBParameterGroupFamily\" --engine <engine>`` \n For example, to list all of the available parameter group families for the Aurora PostgreSQL DB engine, use the following command:\n  ``aws rds describe-db-engine-versions --query \"DBEngineVersions[].DBParameterGroupFamily\" --engine aurora-postgresql`` \n  The output contains duplicates.\n  The following are the valid DB engine values:\n  +   ``aurora-mysql`` \n  +   ``aurora-postgresql`` \n  +   ``mysql`` \n  +   ``postgres``",
      "type" : "string"
    },
    "Parameters" : {
      "description" : "Provides a list of parameters for the DB cluster parameter group.",
      "type" : "object"
    },
    "DBClusterParameterGroupName" : {
      "type" : "string",
      "pattern" : "^[a-zA-Z]{1}(?:-?[a-zA-Z0-9])*$",
      "description" : "The name of the DB cluster parameter group.\n Constraints:\n  +  Must not match the name of an existing DB cluster parameter group.\n  \n  This value is stored as a lowercase string."
    },
    "Tags" : {
      "description" : "Tags to assign to the DB cluster parameter group.",
      "type" : "array",
      "maxItems" : 50,
      "insertionOrder" : False,
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    }
  },
  "additionalProperties" : False,
  "propertyTransform" : {
    "/properties/DBClusterParameterGroupName" : "$lowercase(DBClusterParameterGroupName)"
  },
  "required" : [ "Description", "Family", "Parameters" ],
  "createOnlyProperties" : [ "/properties/DBClusterParameterGroupName", "/properties/Description", "/properties/Family" ],
  "primaryIdentifier" : [ "/properties/DBClusterParameterGroupName" ],
  "handlers" : {
    "create" : {
      "permissions" : [ "iam:CreateServiceLinkedRole", "rds:AddTagsToResource", "rds:CreateDBClusterParameterGroup", "rds:DescribeDBClusterParameterGroups", "rds:DescribeDBClusterParameters", "rds:DescribeDBClusters", "rds:DescribeEngineDefaultClusterParameters", "rds:ListTagsForResource", "rds:ModifyDBClusterParameterGroup", "rds:RemoveTagsFromResource" ],
      "timeoutInMinutes" : 180
    },
    "read" : {
      "permissions" : [ "rds:DescribeDBClusterParameterGroups", "rds:DescribeDBClusterParameters", "rds:DescribeEngineDefaultClusterParameters", "rds:ListTagsForResource" ]
    },
    "update" : {
      "permissions" : [ "rds:AddTagsToResource", "rds:DescribeDBClusterParameterGroups", "rds:DescribeDBClusterParameters", "rds:DescribeDBClusters", "rds:DescribeEngineDefaultClusterParameters", "rds:ListTagsForResource", "rds:ModifyDBClusterParameterGroup", "rds:RemoveTagsFromResource", "rds:ResetDBClusterParameterGroup" ],
      "timeoutInMinutes" : 180
    },
    "delete" : {
      "permissions" : [ "rds:DeleteDBClusterParameterGroup" ]
    },
    "list" : {
      "permissions" : [ "rds:DescribeDBClusterParameterGroups" ]
    }
  },
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : True,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "rds:AddTagsToResource", "rds:RemoveTagsFromResource" ]
  }
}