SCHEMA = {
  "typeName" : "AWS::Route53::HostedZone",
  "description" : "Creates a new public or private hosted zone. You create records in a public hosted zone to define how you want to route traffic on the internet for a domain, such as example.com, and its subdomains (apex.example.com, acme.example.com). You create records in a private hosted zone to define how you want to route traffic for a domain and its subdomains within one or more Amazon Virtual Private Clouds (Amazon VPCs). \n  You can't convert a public hosted zone to a private hosted zone or vice versa. Instead, you must create a new hosted zone with the same name and create new resource record sets.\n  For more information about charges for hosted zones, see [Amazon Route 53 Pricing](https://docs.aws.amazon.com/route53/pricing/).\n Note the following:\n  +  You can't create a hosted zone for a top-level domain (TLD) such as .com.\n  +  If your domain is registered with a registrar other than Route 53, you must update the name servers with your registrar to make Route 53 the DNS service for the domain. For more information, see [Migrating DNS Service for an Existing Domain to Amazon Route 53](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/MigratingDNS.html) in the *Amazon Route 53 Developer Guide*. \n  \n When you submit a ``CreateHostedZone`` request, the initial status of the hosted zone is ``PENDING``. For public hosted zones, this means that the NS and SOA records are not yet available on all Route 53 DNS servers. When the NS and SOA records are available, the status of the zone changes to ``INSYNC``.\n The ``CreateHostedZone`` request requires the caller to have an ``ec2:DescribeVpcs`` permission.\n  When creating private hosted zones, the Amazon VPC must belong to the same partition where the hosted zone is created. A partition is a group of AWS-Regions. Each AWS-account is scoped to one partition.\n The following are the supported partitions:\n  +  ``aws`` - AWS-Regions\n  +  ``aws-cn`` - China Regions\n  +  ``aws-us-gov`` - govcloud-us-region\n  \n For more information, see [Access Management](https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html) in the *General Reference*.",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-route53.git",
  "definitions" : {
    "HostedZoneConfig" : {
      "description" : "A complex type that contains an optional comment about your hosted zone. If you don't want to specify a comment, omit both the ``HostedZoneConfig`` and ``Comment`` elements.",
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Comment" : {
          "description" : "Any comments that you want to include about the hosted zone.",
          "type" : "string",
          "maxLength" : 256
        }
      }
    },
    "HostedZoneTag" : {
      "description" : "A complex type that contains information about a tag that you want to add or edit for the specified health check or hosted zone.",
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Key" : {
          "type" : "string",
          "description" : "The value of ``Key`` depends on the operation that you want to perform:\n  +  *Add a tag to a health check or hosted zone*: ``Key`` is the name that you want to give the new tag.\n  +  *Edit a tag*: ``Key`` is the name of the tag that you want to change the ``Value`` for.\n  +  *Delete a key*: ``Key`` is the name of the tag you want to remove.\n  +  *Give a name to a health check*: Edit the default ``Name`` tag. In the Amazon Route 53 console, the list of your health checks includes a *Name* column that lets you see the name that you've given to each health check.",
          "maxLength" : 128
        },
        "Value" : {
          "type" : "string",
          "description" : "The value of ``Value`` depends on the operation that you want to perform:\n  +  *Add a tag to a health check or hosted zone*: ``Value`` is the value that you want to give the new tag.\n  +  *Edit a tag*: ``Value`` is the new value that you want to assign the tag.",
          "maxLength" : 256
        }
      },
      "required" : [ "Value", "Key" ]
    },
    "QueryLoggingConfig" : {
      "description" : "A complex type that contains information about a configuration for DNS query logging.",
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "CloudWatchLogsLogGroupArn" : {
          "description" : "The Amazon Resource Name (ARN) of the CloudWatch Logs log group that Amazon Route 53 is publishing logs to.",
          "type" : "string",
          "relationshipRef" : {
            "typeName" : "AWS::Logs::LogGroup",
            "propertyPath" : "/properties/Arn"
          }
        }
      },
      "required" : [ "CloudWatchLogsLogGroupArn" ]
    },
    "VPC" : {
      "description" : "*Private hosted zones only:* A complex type that contains information about an Amazon VPC. Route 53 Resolver uses the records in the private hosted zone to route traffic in that VPC. \n  For public hosted zones, omit ``VPCs``, ``VPCId``, and ``VPCRegion``.",
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "VPCId" : {
          "description" : "*Private hosted zones only:* The ID of an Amazon VPC.\n  For public hosted zones, omit ``VPCs``, ``VPCId``, and ``VPCRegion``.",
          "type" : "string",
          "relationshipRef" : {
            "typeName" : "AWS::EC2::VPC",
            "propertyPath" : "/properties/VpcId"
          }
        },
        "VPCRegion" : {
          "description" : "*Private hosted zones only:* The region that an Amazon VPC was created in.\n  For public hosted zones, omit ``VPCs``, ``VPCId``, and ``VPCRegion``.",
          "type" : "string"
        }
      },
      "required" : [ "VPCId", "VPCRegion" ]
    }
  },
  "properties" : {
    "Id" : {
      "type" : "string",
      "description" : ""
    },
    "HostedZoneConfig" : {
      "$ref" : "#/definitions/HostedZoneConfig",
      "description" : "A complex type that contains an optional comment.\n If you don't want to specify a comment, omit the ``HostedZoneConfig`` and ``Comment`` elements."
    },
    "HostedZoneTags" : {
      "description" : "Adds, edits, or deletes tags for a health check or a hosted zone.\n For information about using tags for cost allocation, see [Using Cost Allocation Tags](https://docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html) in the *User Guide*.",
      "type" : "array",
      "uniqueItems" : True,
      "insertionOrder" : False,
      "items" : {
        "$ref" : "#/definitions/HostedZoneTag"
      }
    },
    "Name" : {
      "description" : "The name of the domain. Specify a fully qualified domain name, for example, *www.example.com*. The trailing dot is optional; Amazon Route 53 assumes that the domain name is fully qualified. This means that Route 53 treats *www.example.com* (without a trailing dot) and *www.example.com.* (with a trailing dot) as identical.\n If you're creating a public hosted zone, this is the name you have registered with your DNS registrar. If your domain name is registered with a registrar other than Route 53, change the name servers for your domain to the set of ``NameServers`` that are returned by the ``Fn::GetAtt`` intrinsic function.",
      "type" : "string",
      "maxLength" : 1024
    },
    "QueryLoggingConfig" : {
      "$ref" : "#/definitions/QueryLoggingConfig",
      "description" : "Creates a configuration for DNS query logging. After you create a query logging configuration, Amazon Route 53 begins to publish log data to an Amazon CloudWatch Logs log group.\n DNS query logs contain information about the queries that Route 53 receives for a specified public hosted zone, such as the following:\n  +  Route 53 edge location that responded to the DNS query\n  +  Domain or subdomain that was requested\n  +  DNS record type, such as A or AAAA\n  +  DNS response code, such as ``NoError`` or ``ServFail``\n  \n  + Log Group and Resource Policy Before you create a query logging configuration, perform the following operations. If you create a query logging configuration using the Route 53 console, Route 53 performs these operations automatically. Create a CloudWatch Logs log group, and make note of the ARN, which you specify when you create a query logging configuration. Note the following: You must create the log group in the us-east-1 region. You must use the same to create the log group and the hosted zone that you want to configure query logging for. When you create log groups for query logging, we recommend that you use a consistent prefix, for example: /aws/route53/hosted zone name In the next step, you'll create a resource policy, which controls access to one or more log groups and the associated resources, such as Route 53 hosted zones. There's a limit on the number of resource policies that you can create, so we recommend that you use a consistent prefix so you can use the same resource policy for all the log groups that you create for query logging. Create a CloudWatch Logs resource policy, and give it the permissions that Route 53 needs to create log streams and to send query logs to log streams. You must create the CloudWatch Logs resource policy in the us-east-1 region. For the value of Resource, specify the ARN for the log group that you created in the previous step. To use the same resource policy for all the CloudWatch Logs log groups that you created for query logging configurations, replace the hosted zone name with *, for example: arn:aws:logs:us-east-1:123412341234:log-group:/aws/route53/* To avoid the confused deputy problem, a security issue where an entity without a permission for an action can coerce a more-privileged entity to perform it, you can optionally limit the permissions that a service has to a resource in a resource-based policy by supplying the following values: For aws:SourceArn, supply the hosted zone ARN used in creating the query logging configuration. For example, aws:SourceArn: arn:aws:route53:::hostedzone/hosted zone ID. For aws:SourceAccount, supply the account ID for the account that creates the query logging configuration. For example, aws:SourceAccount:111111111111. For more information, see The confused deputy problem in the IAM User Guide. You can't use the CloudWatch console to create or edit a resource policy. You must use the CloudWatch API, one of the SDKs, or the . + Log Streams and Edge Locations When Route 53 finishes creating the configuration for DNS query logging, it does the following: Creates a log stream for an edge location the first time that the edge location responds to DNS queries for the specified hosted zone. That log stream is used to log all queries that Route 53 responds to for that edge location. Begins to send query logs to the applicable log stream. The name of each log stream is in the following format: hosted zone ID/edge location code The edge location code is a three-letter code and an arbitrarily assigned number, for example, DFW3. The three-letter code typically corresponds with the International Air Transport Association airport code for an airport near the edge location. (These abbreviations might change in the future.) For a list of edge locations, see \"The Route 53 Global Network\" on the Route 53 Product Details page. + Queries That Are Logged Query logs contain only the queries that DNS resolvers forward to Route 53. If a DNS resolver has already cached the response to a query (such as the IP address for a load balancer for example.com), the resolver will continue to return the cached response. It doesn't forward another query to Route 53 until the TTL for the corresponding resource record set expires. Depending on how many DNS queries are submitted for a resource record set, and depending on the TTL for that resource record set, query logs might contain information about only one query out of every several thousand queries that are submitted to DNS. For more information about how DNS works, see Routing Internet Traffic to Your Website or Web Application in the Amazon Route 53 Developer Guide. + Log File Format For a list of the values in each query log and the format of each value, see Logging DNS Queries in the Amazon Route 53 Developer Guide. + Pricing For information about charges for query logs, see Amazon CloudWatch Pricing. + How to Stop Logging If you want Route 53 to stop sending query logs to CloudWatch Logs, delete the query logging configuration. For more information, see DeleteQueryLoggingConfig."
    },
    "VPCs" : {
      "description" : "*Private hosted zones:* A complex type that contains information about the VPCs that are associated with the specified hosted zone.\n  For public hosted zones, omit ``VPCs``, ``VPCId``, and ``VPCRegion``.",
      "type" : "array",
      "uniqueItems" : True,
      "insertionOrder" : False,
      "items" : {
        "$ref" : "#/definitions/VPC"
      }
    },
    "NameServers" : {
      "type" : "array",
      "uniqueItems" : False,
      "items" : {
        "type" : "string"
      },
      "description" : ""
    }
  },
  "additionalProperties" : False,
  "createOnlyProperties" : [ "/properties/Name" ],
  "readOnlyProperties" : [ "/properties/Id", "/properties/NameServers" ],
  "primaryIdentifier" : [ "/properties/Id" ],
  "propertyTransform" : {
    "/properties/Name" : "Name $OR $join([Name, \".\"])"
  },
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : False,
    "tagProperty" : "/properties/HostedZoneTags",
    "permissions" : [ "route53:ChangeTagsForResource", "route53:ListTagsForResource" ]
  },
  "handlers" : {
    "create" : {
      "permissions" : [ "route53:CreateHostedZone", "route53:CreateQueryLoggingConfig", "route53:ChangeTagsForResource", "route53:GetChange", "route53:AssociateVPCWithHostedZone", "ec2:DescribeVpcs" ]
    },
    "read" : {
      "permissions" : [ "route53:GetHostedZone", "route53:ListTagsForResource", "route53:ListQueryLoggingConfigs" ]
    },
    "update" : {
      "permissions" : [ "route53:GetChange", "route53:GetHostedZone", "route53:ListTagsForResource", "route53:ListQueryLoggingConfigs", "route53:UpdateHostedZoneComment", "route53:ChangeTagsForResource", "route53:AssociateVPCWithHostedZone", "route53:DisassociateVPCFromHostedZone", "route53:CreateQueryLoggingConfig", "route53:DeleteQueryLoggingConfig", "ec2:DescribeVpcs" ]
    },
    "delete" : {
      "permissions" : [ "route53:DeleteHostedZone", "route53:DeleteQueryLoggingConfig", "route53:ListQueryLoggingConfigs", "route53:GetChange" ]
    },
    "list" : {
      "permissions" : [ "route53:GetHostedZone", "route53:ListHostedZones", "route53:ListQueryLoggingConfigs", "route53:ListTagsForResource" ]
    }
  }
}