SCHEMA = {
  "tagging" : {
    "permissions" : [ "sagemaker:AddTags", "sagemaker:ListTags", "sagemaker:DeleteTags" ],
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "tagProperty" : "/properties/Tags",
    "cloudFormationSystemTags" : False
  },
  "handlers" : {
    "read" : {
      "permissions" : [ "sagemaker:DescribeCluster", "sagemaker:ListTags" ]
    },
    "create" : {
      "permissions" : [ "sagemaker:CreateCluster", "sagemaker:DescribeCluster", "sagemaker:AddTags", "sagemaker:ListTags", "eks:DescribeAccessEntry", "eks:DescribeCluster", "eks:CreateAccessEntry", "eks:DeleteAccessEntry", "eks:AssociateAccessPolicy", "iam:CreateServiceLinkedRole", "iam:PassRole" ],
      "timeoutInMinutes" : 720
    },
    "update" : {
      "permissions" : [ "sagemaker:UpdateCluster", "sagemaker:DescribeCluster", "sagemaker:ListTags", "sagemaker:AddTags", "sagemaker:DeleteTags", "eks:DescribeAccessEntry", "eks:DescribeCluster", "eks:CreateAccessEntry", "eks:DeleteAccessEntry", "iam:PassRole" ],
      "timeoutInMinutes" : 720
    },
    "list" : {
      "permissions" : [ "sagemaker:ListClusters" ]
    },
    "delete" : {
      "permissions" : [ "sagemaker:DeleteCluster", "sagemaker:DescribeCluster", "eks:DescribeAccessEntry", "eks:DeleteAccessEntry" ],
      "timeoutInMinutes" : 720
    }
  },
  "typeName" : "AWS::SageMaker::Cluster",
  "readOnlyProperties" : [ "/properties/ClusterArn", "/properties/CreationTime", "/properties/ClusterStatus", "/properties/FailureMessage", "/properties/InstanceGroups/*/CurrentCount" ],
  "description" : "Resource Type definition for AWS::SageMaker::Cluster",
  "additionalIdentifiers" : [ [ "/properties/ClusterName" ] ],
  "createOnlyProperties" : [ "/properties/ClusterName", "/properties/VpcConfig", "/properties/Orchestrator", "/properties/InstanceGroups/*/OverrideVpcConfig", "/properties/InstanceGroups/*/ExecutionRole", "/properties/InstanceGroups/*/InstanceGroupName", "/properties/InstanceGroups/*/InstanceType", "/properties/InstanceGroups/*/ThreadsPerCore" ],
  "additionalProperties" : False,
  "primaryIdentifier" : [ "/properties/ClusterArn" ],
  "definitions" : {
    "ClusterOrchestratorEksConfig" : {
      "description" : "Specifies parameter(s) related to EKS as orchestrator, e.g. the EKS cluster nodes will attach to,",
      "additionalProperties" : False,
      "type" : "object",
      "properties" : {
        "ClusterArn" : {
          "description" : "The ARN of the EKS cluster, such as arn:aws:eks:us-west-2:123456789012:cluster/my-eks-cluster",
          "type" : "string"
        }
      },
      "required" : [ "ClusterArn" ]
    },
    "DeepHealthCheckType" : {
      "description" : "The type of deep health check(s) to be performed on the instances in the SageMaker HyperPod cluster instance group.",
      "type" : "string",
      "enum" : [ "InstanceStress", "InstanceConnectivity" ]
    },
    "ClusterInstanceStorageConfig" : {
      "oneOf" : [ {
        "additionalProperties" : False,
        "type" : "object",
        "properties" : {
          "EbsVolumeConfig" : {
            "$ref" : "#/definitions/ClusterEbsVolumeConfig"
          }
        }
      } ],
      "description" : "Defines the configuration for attaching additional storage to the instances in the SageMaker HyperPod cluster instance group.",
      "type" : "object"
    },
    "VpcConfig" : {
      "description" : "Specifies an Amazon Virtual Private Cloud (VPC) that your SageMaker jobs, hosted models, and compute resources have access to. You can control access to and from your resources by configuring a VPC.",
      "additionalProperties" : False,
      "type" : "object",
      "properties" : {
        "Subnets" : {
          "minItems" : 1,
          "maxItems" : 16,
          "description" : "The ID of the subnets in the VPC to which you want to connect your training job or model.",
          "insertionOrder" : False,
          "type" : "array",
          "items" : {
            "pattern" : "[-0-9a-zA-Z]+",
            "type" : "string",
            "maxLength" : 32
          }
        },
        "SecurityGroupIds" : {
          "minItems" : 1,
          "maxItems" : 5,
          "description" : "The VPC security group IDs, in the form sg-xxxxxxxx. Specify the security groups for the VPC that is specified in the Subnets field.",
          "insertionOrder" : False,
          "type" : "array",
          "items" : {
            "pattern" : "[-0-9a-zA-Z]+",
            "type" : "string",
            "maxLength" : 32
          }
        }
      },
      "required" : [ "SecurityGroupIds", "Subnets" ]
    },
    "InstanceGroupName" : {
      "minLength" : 1,
      "pattern" : "^[a-zA-Z0-9](-*[a-zA-Z0-9])*$",
      "description" : "The name of the instance group of a SageMaker HyperPod cluster.",
      "type" : "string",
      "maxLength" : 63
    },
    "ClusterInstanceGroupsList" : {
      "minItems" : 1,
      "description" : "The instance groups of the SageMaker HyperPod cluster.",
      "insertionOrder" : False,
      "type" : "array",
      "items" : {
        "$ref" : "#/definitions/ClusterInstanceGroup"
      }
    },
    "Orchestrator" : {
      "description" : "Specifies parameter(s) specific to the orchestrator, e.g. specify the EKS cluster.",
      "additionalProperties" : False,
      "type" : "object",
      "properties" : {
        "Eks" : {
          "$ref" : "#/definitions/ClusterOrchestratorEksConfig"
        }
      },
      "required" : [ "Eks" ]
    },
    "ClusterEbsVolumeConfig" : {
      "description" : "Defines the configuration for attaching additional Amazon Elastic Block Store (EBS) volumes to the instances in the SageMaker HyperPod cluster instance group. The additional EBS volume is attached to each instance within the SageMaker HyperPod cluster instance group and mounted to /opt/sagemaker.",
      "additionalProperties" : False,
      "type" : "object",
      "properties" : {
        "VolumeSizeInGB" : {
          "description" : "The size in gigabytes (GB) of the additional EBS volume to be attached to the instances in the SageMaker HyperPod cluster instance group. The additional EBS volume is attached to each instance within the SageMaker HyperPod cluster instance group and mounted to /opt/sagemaker.",
          "maximum" : 16384,
          "type" : "integer",
          "minimum" : 1
        }
      }
    },
    "ClusterLifeCycleConfig" : {
      "description" : "The lifecycle configuration for a SageMaker HyperPod cluster.",
      "additionalProperties" : False,
      "type" : "object",
      "properties" : {
        "SourceS3Uri" : {
          "pattern" : "^(https|s3)://([^/]+)/?(.*)$",
          "description" : "An Amazon S3 bucket path where your lifecycle scripts are stored.",
          "type" : "string",
          "maxLength" : 1024
        },
        "OnCreate" : {
          "minLength" : 1,
          "pattern" : "^[\\S\\s]+$",
          "description" : "The file name of the entrypoint script of lifecycle scripts under SourceS3Uri. This entrypoint script runs during cluster creation.",
          "type" : "string",
          "maxLength" : 128
        }
      },
      "required" : [ "OnCreate", "SourceS3Uri" ]
    },
    "OnStartDeepHealthChecks" : {
      "description" : "Nodes will undergo advanced stress test to detect and replace faulty instances, based on the type of deep health check(s) passed in.",
      "insertionOrder" : False,
      "type" : "array",
      "items" : {
        "$ref" : "#/definitions/DeepHealthCheckType"
      }
    },
    "ClusterInstanceGroup" : {
      "description" : "Details of an instance group in a SageMaker HyperPod cluster.",
      "additionalProperties" : False,
      "type" : "object",
      "properties" : {
        "OverrideVpcConfig" : {
          "$ref" : "#/definitions/VpcConfig"
        },
        "InstanceCount" : {
          "description" : "The number of instances you specified to add to the instance group of a SageMaker HyperPod cluster.",
          "type" : "integer",
          "minimum" : 0
        },
        "OnStartDeepHealthChecks" : {
          "$ref" : "#/definitions/OnStartDeepHealthChecks"
        },
        "InstanceGroupName" : {
          "$ref" : "#/definitions/InstanceGroupName"
        },
        "InstanceStorageConfigs" : {
          "$ref" : "#/definitions/ClusterInstanceStorageConfigs"
        },
        "CurrentCount" : {
          "description" : "The number of instances that are currently in the instance group of a SageMaker HyperPod cluster.",
          "type" : "integer",
          "minimum" : 0
        },
        "LifeCycleConfig" : {
          "$ref" : "#/definitions/ClusterLifeCycleConfig"
        },
        "InstanceType" : {
          "$ref" : "#/definitions/InstanceType"
        },
        "ThreadsPerCore" : {
          "description" : "The number you specified to TreadsPerCore in CreateCluster for enabling or disabling multithreading. For instance types that support multithreading, you can specify 1 for disabling multithreading and 2 for enabling multithreading.",
          "maximum" : 2,
          "type" : "integer",
          "minimum" : 1
        },
        "ExecutionRole" : {
          "$ref" : "#/definitions/ExecutionRole"
        }
      },
      "required" : [ "ExecutionRole", "InstanceCount", "InstanceGroupName", "InstanceType", "LifeCycleConfig" ]
    },
    "ClusterInstanceStorageConfigs" : {
      "maxItems" : 1,
      "description" : "The instance storage configuration for the instance group.",
      "insertionOrder" : False,
      "type" : "array",
      "items" : {
        "$ref" : "#/definitions/ClusterInstanceStorageConfig"
      }
    },
    "Tag" : {
      "description" : "A key-value pair to associate with a resource.",
      "additionalProperties" : False,
      "type" : "object",
      "properties" : {
        "Value" : {
          "minLength" : 0,
          "pattern" : "^([\\p{L}\\p{Z}\\p{N}_.:/=+\\-@]*)$",
          "description" : "The value for the tag. You can specify a value that is 0 to 256 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.",
          "type" : "string",
          "maxLength" : 256
        },
        "Key" : {
          "minLength" : 1,
          "pattern" : "^([\\p{L}\\p{Z}\\p{N}_.:/=+\\-@]*)$",
          "description" : "The key name of the tag. You can specify a value that is 1 to 128 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.",
          "type" : "string",
          "maxLength" : 128
        }
      },
      "required" : [ "Key", "Value" ]
    },
    "InstanceType" : {
      "description" : "The instance type of the instance group of a SageMaker HyperPod cluster.",
      "type" : "string"
    },
    "ExecutionRole" : {
      "minLength" : 20,
      "pattern" : "^arn:aws[a-z\\-]*:iam::\\d{12}:role/?[a-zA-Z_0-9+=,.@\\-_/]+$",
      "description" : "The execution role for the instance group to assume.",
      "type" : "string",
      "maxLength" : 2048
    }
  },
  "required" : [ "InstanceGroups" ],
  "properties" : {
    "ClusterArn" : {
      "pattern" : "^arn:aws[a-z\\-]*:sagemaker:[a-z0-9\\-]*:[0-9]{12}:cluster/[a-z0-9]{12}$",
      "description" : "The Amazon Resource Name (ARN) of the HyperPod Cluster.",
      "type" : "string",
      "maxLength" : 256
    },
    "VpcConfig" : {
      "$ref" : "#/definitions/VpcConfig"
    },
    "NodeRecovery" : {
      "description" : "If node auto-recovery is set to True, faulty nodes will be replaced or rebooted when a failure is detected. If set to False, nodes will be labelled when a fault is detected.",
      "type" : "string",
      "enum" : [ "Automatic", "None" ]
    },
    "CreationTime" : {
      "description" : "The time at which the HyperPod cluster was created.",
      "type" : "string"
    },
    "InstanceGroups" : {
      "$ref" : "#/definitions/ClusterInstanceGroupsList"
    },
    "ClusterName" : {
      "minLength" : 1,
      "pattern" : "^[a-zA-Z0-9](-*[a-zA-Z0-9]){0,62}$",
      "description" : "The name of the HyperPod Cluster.",
      "type" : "string",
      "maxLength" : 63
    },
    "FailureMessage" : {
      "description" : "The failure message of the HyperPod Cluster.",
      "type" : "string"
    },
    "Orchestrator" : {
      "$ref" : "#/definitions/Orchestrator"
    },
    "ClusterStatus" : {
      "description" : "The status of the HyperPod Cluster.",
      "type" : "string",
      "enum" : [ "Creating", "Deleting", "Failed", "InService", "RollingBack", "SystemUpdating", "Updating" ]
    },
    "Tags" : {
      "maxItems" : 50,
      "uniqueItems" : True,
      "description" : "Custom tags for managing the SageMaker HyperPod cluster as an AWS resource. You can add tags to your cluster in the same way you add them in other AWS services that support tagging.",
      "insertionOrder" : False,
      "type" : "array",
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    }
  }
}