SCHEMA = {
  "typeName" : "AWS::SNS::Topic",
  "description" : "The ``AWS::SNS::Topic`` resource creates a topic to which notifications can be published.\n  One account can create a maximum of 100,000 standard topics and 1,000 FIFO topics. For more information, see [endpoints and quotas](https://docs.aws.amazon.com/general/latest/gr/sns.html) in the *General Reference*.\n   The structure of ``AUTHPARAMS`` depends on the .signature of the API request. For more information, see [Examples of the complete Signature Version 4 signing process](https://docs.aws.amazon.com/general/latest/gr/sigv4-signed-request-examples.html) in the *General Reference*.",
  "sourceUrl" : "https://github.com/aws-cloudformation/aws-cloudformation-resource-providers-sns",
  "additionalProperties" : False,
  "properties" : {
    "DisplayName" : {
      "description" : "The display name to use for an SNS topic with SMS subscriptions. The display name must be maximum 100 characters long, including hyphens (-), underscores (_), spaces, and tabs.",
      "type" : "string"
    },
    "KmsMasterKeyId" : {
      "description" : "The ID of an AWS managed customer master key (CMK) for SNS or a custom CMK. For more information, see [Key terms](https://docs.aws.amazon.com/sns/latest/dg/sns-server-side-encryption.html#sse-key-terms). For more examples, see ``KeyId`` in the *API Reference*.\n This property applies only to [server-side-encryption](https://docs.aws.amazon.com/sns/latest/dg/sns-server-side-encryption.html).",
      "type" : "string"
    },
    "DataProtectionPolicy" : {
      "description" : "The body of the policy document you want to use for this topic.\n You can only add one policy per topic.\n The policy must be in JSON string format.\n Length Constraints: Maximum length of 30,720.",
      "type" : "object"
    },
    "Subscription" : {
      "description" : "The SNS subscriptions (endpoints) for this topic.\n  If you specify the ``Subscription`` property in the ``AWS::SNS::Topic`` resource and it creates an associated subscription resource, the associated subscription is not deleted when the ``AWS::SNS::Topic`` resource is deleted.",
      "type" : "array",
      "uniqueItems" : False,
      "insertionOrder" : False,
      "items" : {
        "$ref" : "#/definitions/Subscription"
      }
    },
    "FifoTopic" : {
      "description" : "Set to True to create a FIFO topic.",
      "type" : "boolean"
    },
    "ContentBasedDeduplication" : {
      "description" : "Enables content-based deduplication for FIFO topics.\n  +  By default, ``ContentBasedDeduplication`` is set to ``False``. If you create a FIFO topic and this attribute is ``false``, you must specify a value for the ``MessageDeduplicationId`` parameter for the [Publish](https://docs.aws.amazon.com/sns/latest/api/API_Publish.html) action. \n  +  When you set ``ContentBasedDeduplication`` to ``True``, SNS uses a SHA-256 hash to generate the ``MessageDeduplicationId`` using the body of the message (but not the attributes of the message).\n (Optional) To override the generated value, you can specify a value for the the ``MessageDeduplicationId`` parameter for the ``Publish`` action.",
      "type" : "boolean"
    },
    "ArchivePolicy" : {
      "description" : "The archive policy determines the number of days SNS retains messages. You can set a retention period from 1 to 365 days.",
      "type" : "object"
    },
    "FifoThroughputScope" : {
      "description" : "",
      "type" : "string"
    },
    "Tags" : {
      "type" : "array",
      "uniqueItems" : False,
      "insertionOrder" : False,
      "items" : {
        "$ref" : "#/definitions/Tag"
      },
      "description" : "The list of tags to add to a new topic.\n  To be able to tag a topic on creation, you must have the ``sns:CreateTopic`` and ``sns:TagResource`` permissions."
    },
    "TopicName" : {
      "description" : "The name of the topic you want to create. Topic names must include only uppercase and lowercase ASCII letters, numbers, underscores, and hyphens, and must be between 1 and 256 characters long. FIFO topic names must end with ``.fifo``.\n If you don't specify a name, CFN generates a unique physical ID and uses that ID for the topic name. For more information, see [Name type](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-name.html).\n  If you specify a name, you can't perform updates that require replacement of this resource. You can perform updates that require no or some interruption. If you must replace the resource, specify a new name.",
      "type" : "string"
    },
    "TopicArn" : {
      "type" : "string",
      "description" : ""
    },
    "SignatureVersion" : {
      "description" : "The signature version corresponds to the hashing algorithm used while creating the signature of the notifications, subscription confirmations, or unsubscribe confirmation messages sent by Amazon SNS. By default, ``SignatureVersion`` is set to ``1``.",
      "type" : "string"
    },
    "TracingConfig" : {
      "description" : "Tracing mode of an SNS topic. By default ``TracingConfig`` is set to ``PassThrough``, and the topic passes through the tracing header it receives from an SNS publisher to its subscriptions. If set to ``Active``, SNS will vend X-Ray segment data to topic owner account if the sampled flag in the tracing header is True.",
      "type" : "string"
    },
    "DeliveryStatusLogging" : {
      "description" : "The ``DeliveryStatusLogging`` configuration enables you to log the delivery status of messages sent from your Amazon SNS topic to subscribed endpoints with the following supported delivery protocols:\n  +  HTTP \n  +  Amazon Kinesis Data Firehose\n  +   AWS Lambda\n  +  Platform application endpoint\n  +  Amazon Simple Queue Service\n  \n Once configured, log entries are sent to Amazon CloudWatch Logs.",
      "type" : "array",
      "uniqueItems" : True,
      "insertionOrder" : False,
      "items" : {
        "$ref" : "#/definitions/LoggingConfig"
      }
    }
  },
  "definitions" : {
    "Tag" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Key" : {
          "type" : "string",
          "description" : "The required key portion of the tag."
        },
        "Value" : {
          "type" : "string",
          "description" : "The optional value portion of the tag."
        }
      },
      "required" : [ "Value", "Key" ],
      "description" : "The list of tags to be added to the specified topic."
    },
    "Subscription" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Endpoint" : {
          "type" : "string",
          "description" : "The endpoint that receives notifications from the SNS topic. The endpoint value depends on the protocol that you specify. For more information, see the ``Endpoint`` parameter of the ``Subscribe`` action in the *API Reference*."
        },
        "Protocol" : {
          "type" : "string",
          "description" : "The subscription's protocol. For more information, see the ``Protocol`` parameter of the ``Subscribe`` action in the *API Reference*."
        }
      },
      "required" : [ "Endpoint", "Protocol" ],
      "description" : "``Subscription`` is an embedded property that describes the subscription endpoints of an SNS topic.\n  For full control over subscription behavior (for example, delivery policy, filtering, raw message delivery, and cross-region subscriptions), use the [AWS::SNS::Subscription](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sns-subscription.html) resource."
    },
    "LoggingConfig" : {
      "type" : "object",
      "additionalProperties" : False,
      "properties" : {
        "Protocol" : {
          "type" : "string",
          "description" : "Indicates one of the supported protocols for the Amazon SNS topic.\n  At least one of the other three ``LoggingConfig`` properties is recommend along with ``Protocol``.",
          "enum" : [ "http/s", "sqs", "lambda", "firehose", "application" ]
        },
        "SuccessFeedbackRoleArn" : {
          "type" : "string",
          "description" : "The IAM role ARN to be used when logging successful message deliveries in Amazon CloudWatch."
        },
        "SuccessFeedbackSampleRate" : {
          "type" : "string",
          "description" : "The percentage of successful message deliveries to be logged in Amazon CloudWatch. Valid percentage values range from 0 to 100."
        },
        "FailureFeedbackRoleArn" : {
          "type" : "string",
          "description" : "The IAM role ARN to be used when logging failed message deliveries in Amazon CloudWatch."
        }
      },
      "required" : [ "Protocol" ],
      "description" : "The ``LoggingConfig`` property type specifies the ``Delivery`` status logging configuration for an [AWS::SNS::Topic](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sns-topic.html)."
    }
  },
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : True,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "sns:TagResource", "sns:UntagResource", "sns:ListTagsForResource" ]
  },
  "createOnlyProperties" : [ "/properties/TopicName", "/properties/FifoTopic" ],
  "primaryIdentifier" : [ "/properties/TopicArn" ],
  "readOnlyProperties" : [ "/properties/TopicArn" ],
  "handlers" : {
    "create" : {
      "permissions" : [ "sns:CreateTopic", "sns:TagResource", "sns:Subscribe", "sns:GetTopicAttributes", "sns:PutDataProtectionPolicy", "iam:GetRole", "iam:PassRole" ]
    },
    "read" : {
      "permissions" : [ "sns:GetTopicAttributes", "sns:ListTagsForResource", "sns:ListSubscriptionsByTopic", "sns:GetDataProtectionPolicy" ]
    },
    "update" : {
      "permissions" : [ "sns:SetTopicAttributes", "sns:TagResource", "sns:UntagResource", "sns:Subscribe", "sns:Unsubscribe", "sns:GetTopicAttributes", "sns:ListTagsForResource", "sns:ListSubscriptionsByTopic", "sns:GetDataProtectionPolicy", "sns:PutDataProtectionPolicy", "iam:GetRole", "iam:PassRole" ]
    },
    "delete" : {
      "permissions" : [ "sns:GetTopicAttributes", "sns:DeleteTopic" ]
    },
    "list" : {
      "permissions" : [ "sns:ListTopics" ]
    }
  }
}