SCHEMA = {
  "typeName" : "AWS::Transfer::Connector",
  "description" : "Resource Type definition for AWS::Transfer::Connector",
  "definitions" : {
    "Tag" : {
      "description" : "Creates a key-value pair for a specific resource.",
      "type" : "object",
      "properties" : {
        "Key" : {
          "type" : "string",
          "description" : "The name assigned to the tag that you create.",
          "minLength" : 1,
          "maxLength" : 128
        },
        "Value" : {
          "type" : "string",
          "description" : "Contains one or more values that you assigned to the key name you create.",
          "minLength" : 0,
          "maxLength" : 256
        }
      },
      "required" : [ "Key", "Value" ],
      "additionalProperties" : False
    },
    "SftpConnectorTrustedHostKey" : {
      "description" : "The public host key for the external server to which you are connecting.",
      "type" : "string",
      "minLength" : 1,
      "maxLength" : 2048
    }
  },
  "properties" : {
    "AccessRole" : {
      "description" : "Specifies the access role for the connector.",
      "type" : "string",
      "pattern" : "arn:.*role/.*",
      "minLength" : 20,
      "maxLength" : 2048
    },
    "As2Config" : {
      "description" : "Configuration for an AS2 connector.",
      "type" : "object",
      "properties" : {
        "LocalProfileId" : {
          "type" : "string",
          "description" : "A unique identifier for the local profile.",
          "pattern" : "^p-([0-9a-f]{17})$",
          "minLength" : 19,
          "maxLength" : 19
        },
        "PartnerProfileId" : {
          "type" : "string",
          "description" : "A unique identifier for the partner profile.",
          "pattern" : "^p-([0-9a-f]{17})$",
          "minLength" : 19,
          "maxLength" : 19
        },
        "MessageSubject" : {
          "type" : "string",
          "description" : "The message subject for this AS2 connector configuration.",
          "pattern" : "^[\\u0020-\\u007E\\t]+$",
          "minLength" : 1,
          "maxLength" : 1024
        },
        "Compression" : {
          "type" : "string",
          "description" : "Compression setting for this AS2 connector configuration.",
          "enum" : [ "ZLIB", "DISABLED" ]
        },
        "EncryptionAlgorithm" : {
          "type" : "string",
          "description" : "Encryption algorithm for this AS2 connector configuration.",
          "enum" : [ "AES128_CBC", "AES192_CBC", "AES256_CBC", "NONE", "DES_EDE3_CBC" ]
        },
        "SigningAlgorithm" : {
          "type" : "string",
          "description" : "Signing algorithm for this AS2 connector configuration.",
          "enum" : [ "SHA256", "SHA384", "SHA512", "SHA1", "NONE" ]
        },
        "MdnSigningAlgorithm" : {
          "type" : "string",
          "description" : "MDN Signing algorithm for this AS2 connector configuration.",
          "enum" : [ "SHA256", "SHA384", "SHA512", "SHA1", "NONE", "DEFAULT" ]
        },
        "MdnResponse" : {
          "type" : "string",
          "description" : "MDN Response setting for this AS2 connector configuration.",
          "enum" : [ "SYNC", "NONE" ]
        },
        "BasicAuthSecretId" : {
          "type" : "string",
          "description" : "ARN or name of the secret in AWS Secrets Manager which contains the credentials for Basic authentication. If empty, Basic authentication is disabled for the AS2 connector",
          "minLength" : 0,
          "maxLength" : 2048
        },
        "PreserveContentType" : {
          "description" : "Specifies whether to use the AWS S3 object content-type as the content-type for the AS2 message.",
          "type" : "string",
          "enum" : [ "ENABLED", "DISABLED" ]
        }
      },
      "additionalProperties" : False
    },
    "SftpConfig" : {
      "description" : "Configuration for an SFTP connector.",
      "type" : "object",
      "properties" : {
        "UserSecretId" : {
          "type" : "string",
          "description" : "ARN or name of the secret in AWS Secrets Manager which contains the SFTP user's private keys or passwords.",
          "minLength" : 1,
          "maxLength" : 2048
        },
        "TrustedHostKeys" : {
          "description" : "List of public host keys, for the external server to which you are connecting.",
          "type" : "array",
          "maxItems" : 10,
          "uniqueItems" : False,
          "insertionOrder" : False,
          "items" : {
            "$ref" : "#/definitions/SftpConnectorTrustedHostKey"
          }
        }
      },
      "additionalProperties" : False
    },
    "Arn" : {
      "description" : "Specifies the unique Amazon Resource Name (ARN) for the connector.",
      "type" : "string",
      "pattern" : "arn:.*",
      "minLength" : 20,
      "maxLength" : 1600
    },
    "ConnectorId" : {
      "description" : "A unique identifier for the connector.",
      "type" : "string",
      "pattern" : "^c-([0-9a-f]{17})$",
      "minLength" : 19,
      "maxLength" : 19
    },
    "LoggingRole" : {
      "description" : "Specifies the logging role for the connector.",
      "type" : "string",
      "pattern" : "arn:.*role/.*",
      "minLength" : 20,
      "maxLength" : 2048
    },
    "ServiceManagedEgressIpAddresses" : {
      "description" : "The list of egress IP addresses of this connector. These IP addresses are assigned automatically when you create the connector.",
      "type" : "array",
      "insertionOrder" : False,
      "items" : {
        "type" : "string",
        "pattern" : "^\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}$"
      }
    },
    "Tags" : {
      "description" : "Key-value pairs that can be used to group and search for connectors. Tags are metadata attached to connectors for any purpose.",
      "type" : "array",
      "maxItems" : 50,
      "uniqueItems" : True,
      "insertionOrder" : False,
      "items" : {
        "$ref" : "#/definitions/Tag"
      }
    },
    "Url" : {
      "description" : "URL for Connector",
      "type" : "string",
      "maxLength" : 255
    },
    "SecurityPolicyName" : {
      "description" : "Security policy for SFTP Connector",
      "type" : "string",
      "pattern" : "TransferSFTPConnectorSecurityPolicy-[A-Za-z0-9-]+",
      "maxLength" : 50
    }
  },
  "additionalProperties" : False,
  "required" : [ "AccessRole", "Url" ],
  "readOnlyProperties" : [ "/properties/Arn", "/properties/ConnectorId", "/properties/ServiceManagedEgressIpAddresses" ],
  "primaryIdentifier" : [ "/properties/ConnectorId" ],
  "tagging" : {
    "taggable" : True,
    "tagOnCreate" : True,
    "tagUpdatable" : True,
    "cloudFormationSystemTags" : True,
    "tagProperty" : "/properties/Tags",
    "permissions" : [ "transfer:ListTagsForResource", "transfer:UnTagResource", "transfer:TagResource" ]
  },
  "handlers" : {
    "create" : {
      "permissions" : [ "transfer:CreateConnector", "transfer:TagResource", "iam:PassRole" ]
    },
    "read" : {
      "permissions" : [ "transfer:DescribeConnector" ]
    },
    "update" : {
      "permissions" : [ "transfer:UpdateConnector", "transfer:UnTagResource", "transfer:TagResource", "iam:PassRole" ]
    },
    "delete" : {
      "permissions" : [ "transfer:DeleteConnector" ]
    },
    "list" : {
      "permissions" : [ "transfer:ListConnectors" ]
    }
  }
}